@@ -27,13 +27,12 @@
 #include <sys/types.h>
 #include <fcntl.h>
 #include <errno.h>
-#include <gnome.h>
-#include <glade/glade.h>
-#include <libgnomeui/gnome-window-icon.h>
+#include <gtk/gtk.h>
 #include <panel-applet-gconf.h>
 
 #include <signal.h>
 
+#include "gpilotd/gpilot-daemon.h"
 #include "gpilot-applet-progress.h"
 #include "gpilotd/gnome-pilot-client.h"
 
@@ -59,6 +58,7 @@ typedef struct {
 
 typedef enum { INITIALISING, PAUSED, CONNECTING_TO_DAEMON, SYNCING, WAITING, NUM_STATES } state;
 
+
 char *pixmaps[] = 
 {
     GNOME_ICONDIR "/sync_broken.png",
@@ -71,7 +71,6 @@ char *pixmaps[] =
 
 typedef struct {
 	PanelApplet *applet;
-	GtkTooltips *tooltips;
 	pilot_properties properties; /* = { NULL }; */
 	state curstate;
 	GtkWidget *image; 
@@ -94,16 +93,14 @@ typedef struct {
 	GtkWidget *chooseDialog; 
 	GtkWidget *restoreDialog;
 	GdkColor  errorColor;
-	gchar* glade_file;
+	gchar    *ui_file;
 
 	GnomePilotClient *gpc;
 } PilotApplet;
 
 #define PILOT_APPLET(x) ((PilotApplet*)(x))
 
-static void show_error_dialog (PilotApplet *self, gchar*,...);
-static void show_warning_dialog (PilotApplet *self, gchar*,...);
-static void show_message_dialog (PilotApplet *self, gchar*,...);
+static void show_dialog (PilotApplet *self, GtkMessageType type, gchar*,...);
 static void cancel_cb (GtkButton* button, gpointer whatever);
 
 static void save_properties (PilotApplet *self);
@@ -123,6 +120,25 @@ static gboolean timeout (PilotApplet *self);
 
 /******************************************************************/
 
+static GtkBuilder *
+load_ui (const gchar *filename, const gchar *widget)
+{
+	GtkBuilder *ui;
+	gchar *objects[2] = {NULL, NULL};
+
+	ui = gtk_builder_new ();
+	objects[0] = (gchar *)widget;
+	gtk_builder_add_objects_from_file (ui, filename, objects, NULL);
+
+	return ui;
+}
+
+static GtkWidget *
+get_widget (GtkBuilder *ui, const gchar *name)
+{
+	return GTK_WIDGET (gtk_builder_get_object (ui, name));
+}
+
 static void 
 gpilotd_connect_cb (GnomePilotClient *client, 
 		    const gchar *id,
@@ -131,35 +147,37 @@ gpilotd_connect_cb (GnomePilotClient *client,
 {
 	GdkColormap *colormap;
 	gchar *buf;
+	GError *error = NULL;
 	PilotApplet *applet = PILOT_APPLET (user_data);
 
-	gtk_tooltips_set_tip (applet->tooltips, GTK_WIDGET(applet->applet),
-			("Synchronizing..."), NULL);
+	gtk_widget_set_tooltip_text(GTK_WIDGET(applet->applet), _("Synchronizing..."));
   
 	if (!GTK_WIDGET_REALIZED (applet->image)) {
 		g_warning ("! realized");
 		return;
 	}
 	applet->curstate = SYNCING;
+	g_message ("state = SYNCING");
+
 	pilot_draw (applet);
 
 	if (applet->properties.popups == FALSE) return;
 
 	if (applet->progressDialog == NULL) {
-		gnome_window_icon_set_default_from_file (
-				GNOME_ICONDIR "/sync_icon.png");
-		GladeXML *xml              = glade_xml_new (applet->glade_file,"ProgressDialog",NULL);
-		applet->progressDialog       = glade_xml_get_widget (xml,"ProgressDialog");
-		applet->sync_label           = glade_xml_get_widget (xml,"sync_label");
-		applet->message_area         = glade_xml_get_widget (xml,"message_area");
-		applet->overall_progress_bar = glade_xml_get_widget (xml,"overall_progress_bar");
-		applet->conduit_progress_bar = glade_xml_get_widget (xml,"conduit_progress_bar");
-		applet->cancel_button        = glade_xml_get_widget (xml,"cancel_button");
+		gtk_window_set_default_icon_from_file (
+		    GNOME_ICONDIR "/sync_icon.png", &error);
+		GtkBuilder *ui               = load_ui (applet->ui_file,"ProgressDialog");
+		applet->progressDialog       = get_widget (ui,"ProgressDialog");
+		applet->sync_label           = get_widget (ui,"sync_label");
+		applet->message_area         = get_widget (ui,"message_area");
+		applet->overall_progress_bar = get_widget (ui,"overall_progress_bar");
+		applet->conduit_progress_bar = get_widget (ui,"conduit_progress_bar");
+		applet->cancel_button        = get_widget (ui,"cancel_button");
 		applet->message_buffer       = gtk_text_view_get_buffer(
 				GTK_TEXT_VIEW(applet->message_area));
 
-		gtk_signal_connect (GTK_OBJECT (applet->cancel_button),"clicked",
-				   GTK_SIGNAL_FUNC (cancel_cb),applet);
+		g_signal_connect   (GTK_OBJECT (applet->cancel_button),"clicked",
+				   G_CALLBACK (cancel_cb),applet);
 	} else {
 		gtk_text_buffer_set_text (applet->message_buffer, "", -1);
 	}
@@ -170,15 +188,16 @@ gpilotd_connect_cb (GnomePilotClient *client,
 	g_free (buf);
 	gtk_widget_show_all (applet->progressDialog);
 
-	gtk_progress_set_format_string (GTK_PROGRESS (applet->overall_progress_bar), _("Database %v of %u"));
-	gtk_progress_set_format_string (GTK_PROGRESS (applet->conduit_progress_bar), "");
-	gtk_progress_configure (GTK_PROGRESS (applet->overall_progress_bar),0 ,0, 1);
-	gtk_progress_configure (GTK_PROGRESS (applet->conduit_progress_bar),0 ,0, 100.0);
+	gtk_progress_bar_set_text (GTK_PROGRESS_BAR (applet->overall_progress_bar), _("Connecting..."));
+	gtk_progress_bar_set_text (GTK_PROGRESS_BAR (applet->conduit_progress_bar), "");
+	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (applet->overall_progress_bar),0);
+	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (applet->conduit_progress_bar),0);
 
-	gpilot_applet_progress_set_progress (applet->c_progress, GTK_PROGRESS (applet->conduit_progress_bar));
+	gpilot_applet_progress_set_progress (applet->c_progress, GTK_PROGRESS_BAR (
+		applet->conduit_progress_bar));
 	gpilot_applet_progress_start (applet->c_progress);
 
-	colormap = gdk_window_get_colormap (applet->message_area->window);
+	colormap = gdk_drawable_get_colormap (applet->message_area->window);
 	gdk_color_parse ("red",&(applet->errorColor));
 	gdk_colormap_alloc_color (colormap,&(applet->errorColor),FALSE,TRUE);
 }
@@ -189,10 +208,11 @@ gpilotd_disconnect_cb (GnomePilotClient *client,
 		       gpointer user_data)
 {
 	PilotApplet *applet = PILOT_APPLET (user_data);
-	gtk_tooltips_set_tip (applet->tooltips, GTK_WIDGET(applet->applet),
-			("Ready to synchronize"), NULL);
+	gtk_widget_set_tooltip_text(GTK_WIDGET(applet->applet), _("Ready to synchronize"));
 
 	applet->curstate = WAITING;
+	g_message ("state = READY");
+
 	pilot_draw (applet);
 	if (applet->properties.popups && applet->progressDialog!=NULL) {
 		gpilot_applet_progress_stop (applet->c_progress);
@@ -215,7 +235,7 @@ applet_back_change (PanelApplet			*a,
         gtk_widget_set_style (GTK_WIDGET (applet->applet), NULL);
         rc_style = gtk_rc_style_new ();
         gtk_widget_modify_style (GTK_WIDGET (applet->applet), rc_style);
-        gtk_rc_style_unref (rc_style);
+        g_object_unref (rc_style);
 
         switch (type) {
                 case PANEL_COLOR_BACKGROUND:
@@ -262,6 +282,11 @@ gpilotd_request_completed (GnomePilotClient *client,
 {
 	PilotApplet *applet = PILOT_APPLET (user_data);
 
+
+	/* could happen, if gpilotd-client is used, for example */
+	if (applet->operationDialogWindow == NULL)
+	    return;
+
 	gtk_dialog_response (GTK_DIALOG (applet->operationDialogWindow), GTK_RESPONSE_CLOSE);
 	if (applet->properties.popups && applet->progressDialog !=NULL) {
 		gchar *txt=g_strdup_printf (_("Request %ld has been completed\n"),handle);
@@ -288,7 +313,7 @@ gpilotd_conduit_start (GnomePilotClient* client,
 	if (applet->properties.popups && applet->progressDialog!=NULL) {
 		gchar *txt=g_strdup_printf (_("%s Synchronizing : %s"),id, conduit);
 		gtk_label_set_text (GTK_LABEL (applet->sync_label),txt);
-		gtk_progress_configure (GTK_PROGRESS (applet->conduit_progress_bar), 0, 0, 100);
+		gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (applet->conduit_progress_bar), 0);
 		gpilot_applet_progress_start (applet->c_progress);
 		g_free (txt);
 		txt=g_strdup_printf (_("%s: Started\n"),conduit);
@@ -307,14 +332,14 @@ gpilotd_conduit_end (GnomePilotClient* client,
 	PilotApplet *applet = PILOT_APPLET (user_data);
 	if (applet->properties.popups && applet->progressDialog!=NULL) {
 		gchar *txt=g_strdup_printf (_("%s Finished : %s"),id, conduit);
-		gtk_progress_configure (GTK_PROGRESS (applet->conduit_progress_bar),100,0,100);
+		gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (applet->conduit_progress_bar),1.0);
 		gpilot_applet_progress_start (applet->c_progress);
 		gtk_label_set_text (GTK_LABEL (applet->sync_label),txt);
 		g_free (txt);
 		txt=g_strdup_printf (_("%s: Ended\n"),conduit);
 		gtk_text_buffer_insert_at_cursor (applet->message_buffer,txt,-1);
 		g_free (txt);
-		gtk_progress_set_format_string (GTK_PROGRESS (applet->conduit_progress_bar), "");
+		gtk_progress_bar_set_text (GTK_PROGRESS_BAR (applet->conduit_progress_bar), "");
 		gpilotd_scroll_to_insert_mark(applet);
 	}
 }
@@ -328,19 +353,20 @@ gpilotd_conduit_progress (GnomePilotClient* client,
 			  gpointer user_data)
 {
 	PilotApplet *applet = PILOT_APPLET (user_data);
-	gfloat tot_f,cur_f;
-	tot_f = total;
-	cur_f = current;
+	gdouble cur_f = (gdouble)current/(gdouble)total;
+	gchar *buf = NULL;
 /*
         g_message ("%s : %s : %d/%d = %d%%",id, conduit, current, 
         total,abs (cur_f/(tot_f/100)));
 */
 	if (applet->properties.popups && applet->progressDialog!=NULL) {
-		gtk_progress_configure (GTK_PROGRESS (applet->conduit_progress_bar), cur_f, 1, tot_f); 
-		gtk_progress_set_format_string (GTK_PROGRESS (applet->conduit_progress_bar), _("%v of %u records"));
+		gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (applet->conduit_progress_bar), cur_f); 
+		buf = g_strdup_printf (_("%d of %d records"), current, total);
+		gtk_progress_bar_set_text (GTK_PROGRESS_BAR (applet->conduit_progress_bar), buf);
+		g_free (buf);
 		gpilot_applet_progress_stop (applet->c_progress);
 	}
-	g_main_iteration (FALSE);
+	g_main_context_iteration (NULL, FALSE);
 }
 
 static void 
@@ -352,15 +378,14 @@ gpilotd_overall_progress (GnomePilotClient* client,
 {
 	PilotApplet *applet = PILOT_APPLET (user_data);
 
-	gfloat tot_f,cur_f;
-	tot_f = total;
-	cur_f = current;
-
+	gdouble cur_f = (gdouble)current/(gdouble)total;
 
 	if (applet->properties.popups && applet->progressDialog!=NULL) {
-		gtk_progress_configure (GTK_PROGRESS (applet->overall_progress_bar),cur_f,0,tot_f);
+		gchar *buf=g_strdup_printf (_("Database %d of %d"), current, total);
+		gtk_progress_bar_set_text (GTK_PROGRESS_BAR (applet->overall_progress_bar), buf);
+		gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (applet->overall_progress_bar),cur_f);
 	}
-	g_main_iteration (FALSE);
+	g_main_context_iteration (NULL, FALSE);
 }
 
 static void 
@@ -377,7 +402,7 @@ gpilotd_conduit_message (GnomePilotClient* client,
 		g_free (txt);
 		gpilotd_scroll_to_insert_mark(applet);
 	}
-	g_main_iteration (FALSE);
+	g_main_context_iteration (NULL, FALSE);
 }
 
 static void 
@@ -394,7 +419,7 @@ gpilotd_daemon_message (GnomePilotClient* client,
 		g_free (txt);
 		gpilotd_scroll_to_insert_mark(applet);
 	}
-	g_main_iteration (FALSE);
+	g_main_context_iteration (NULL, FALSE);
 }
 
 static void 
@@ -416,18 +441,26 @@ static void
 handle_client_error (PilotApplet *self)
 {
 	if (self->curstate == SYNCING) {
-		show_warning_dialog (self, _("PDA is currently synchronizing.\nPlease wait for it to finish."));
+		show_dialog (self, GTK_MESSAGE_WARNING,
+		    _("PDA is currently synchronizing.\nPlease wait for it to finish."));
 	} else {
 		self->curstate=INITIALISING;
-		gtk_tooltips_set_tip (self->tooltips, GTK_WIDGET (self->applet),_("Not connected. Please restart daemon."), NULL);	
+		g_message ("state = INITIALISING");
+		gtk_widget_set_tooltip_text(GTK_WIDGET(self->applet),
+		    _("Not connected. Please restart daemon."));
+		
 		pilot_draw (self);
-		show_error_dialog (self, _("Not connected to gpilotd.\nPlease restart daemon."));
+		show_dialog (self, GTK_MESSAGE_ERROR,
+		    _("Not connected to gpilotd.\nPlease restart daemon."));
 	}
 }
 
 static void
 about_cb(BonoboUIComponent *uic, PilotApplet *pilot, const gchar *verbname)
+
 {
+	GError *error = NULL;
+
 	GtkWidget *about;
 	const gchar *authors[] = {"Vadim Strizhevsky <vadim@optonline.net>",
 				  "Eskil Heyn Olsen, <eskil@eskil.dk>",
@@ -435,18 +468,26 @@ about_cb(BonoboUIComponent *uic, PilotApplet *pilot, const gchar *verbname)
 				  "Chris Toshok <toshok@ximian.com>",
 				  "Frank Belew <frb@ximian.com>",
 				  "Matt Davey <mcdavey@mrao.cam.ac.uk>",
+				  "Halton Huo <haltonhuo@gnome.org>",
 				  NULL};
 
-	gnome_window_icon_set_default_from_file (
-				GNOME_ICONDIR "/sync_icon.png");
-	about = gnome_about_new (_("gnome-pilot applet"), 
-				 VERSION,
-				 _("Copyright 2000-2006 Free Software Foundation, Inc."),
-				 _("A PalmOS PDA monitor.\n"),
-				 (const gchar**)authors,
-				 NULL,
-				 "Translations by the GNOME Translation Project",
-				 NULL /* pixbuf */);
+	gtk_window_set_default_icon_from_file (
+	    GNOME_ICONDIR "/sync_icon.png", &error);
+
+
+	if (error != NULL)
+	{
+	    g_warning ("Error setting icon: " GNOME_ICONDIR "/sync_icon.png: %s", error->message );
+	}
+
+	about = gtk_about_dialog_new ();
+        gtk_about_dialog_set_program_name (GTK_ABOUT_DIALOG (about), _("gnome-pilot applet"));
+        gtk_about_dialog_set_version (GTK_ABOUT_DIALOG (about), VERSION);
+        gtk_about_dialog_set_copyright (GTK_ABOUT_DIALOG (about), _("Copyright 2000-2006 Free Software Foundation, Inc."));
+        gtk_about_dialog_set_comments (GTK_ABOUT_DIALOG (about), _("A PalmOS PDA monitor.\n"));
+        gtk_about_dialog_set_authors (GTK_ABOUT_DIALOG (about), (const gchar**)authors);
+        gtk_about_dialog_set_translator_credits (GTK_ABOUT_DIALOG (about), "Translations by the GNOME Translation Project");
+        gtk_about_dialog_set_logo_icon_name (GTK_ABOUT_DIALOG (about), "palm-pilot-sync");
 
 	gtk_window_set_wmclass (
 		GTK_WINDOW (about), "pilot", "Pilot");
@@ -455,7 +496,8 @@ about_cb(BonoboUIComponent *uic, PilotApplet *pilot, const gchar *verbname)
 	gtk_window_set_screen (GTK_WINDOW (about),
 		gtk_widget_get_screen (GTK_WIDGET (pilot->applet)));
 
-	gtk_widget_show (about);
+	gtk_dialog_run (GTK_DIALOG(about));
+	gtk_widget_destroy (about);
 
 	return;
 }
@@ -492,24 +534,25 @@ properties_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname
 {
 	PilotApplet *self = user_data;
 	GtkWidget *button, *entry, *dialog;
-	GladeXML *xml;
+	GtkBuilder *ui;
+	GError *error = NULL;
 
-	gnome_window_icon_set_default_from_file (GNOME_ICONDIR "/sync_icon.png");
-	xml =glade_xml_new (self->glade_file,"PropertiesDialog", NULL);
-	dialog=glade_xml_get_widget (xml,"PropertiesDialog");
+	gtk_window_set_default_icon_from_file (GNOME_ICONDIR "/sync_icon.png", &error);
+	ui = load_ui (self->ui_file,"PropertiesDialog");
+	dialog = get_widget (ui,"PropertiesDialog");
 	
-	entry = glade_xml_get_widget (xml,"exec_entry");
+	entry = get_widget (ui,"exec_entry");
 	if (self->properties.exec_when_clicked)
 		gtk_entry_set_text (GTK_ENTRY (entry), self->properties.exec_when_clicked);
-	gtk_signal_connect (GTK_OBJECT (entry), "focus-out-event",
-			    GTK_SIGNAL_FUNC (exec_on_click_changed_cb),
+	g_signal_connect   (GTK_OBJECT (entry), "focus-out-event",
+			    G_CALLBACK (exec_on_click_changed_cb),
 			    self);
 
   
-	button = glade_xml_get_widget (xml,"notices_button");
-	gtk_toggle_button_set_state (GTK_TOGGLE_BUTTON (button), self->properties.popups);
-	gtk_signal_connect (GTK_OBJECT (button), "toggled",
-			    GTK_SIGNAL_FUNC (toggle_notices_cb),
+	button = get_widget (ui,"notices_button");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), self->properties.popups);
+	g_signal_connect   (GTK_OBJECT (button), "toggled",
+			    G_CALLBACK (toggle_notices_cb),
 			    self);
 
 	g_signal_connect (GTK_OBJECT (dialog), "response",
@@ -528,9 +571,10 @@ help_cb(BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
 	PilotApplet *applet = user_data;
 	GError *error = NULL;
 
-	gnome_help_display_on_screen  ("gnome-pilot", "pilot-applet",
-				       (gtk_widget_get_screen(GTK_WIDGET (applet->applet))),
-				       &error);
+	gtk_show_uri (gtk_widget_get_screen(GTK_WIDGET (applet->applet)),
+		      "ghelp:gnome-pilot#pilot-applet",
+		      gtk_get_current_event_time (),
+		      &error);
 
 	if (error)
 	{
@@ -554,9 +598,10 @@ static void
 pref_help_cb(GtkDialog *dialog)
 {
 	GError *error = NULL;
-	gnome_help_display_on_screen  ("gnome-pilot", NULL /* FIXME Add section id later */,
-				       gtk_widget_get_screen (GTK_WIDGET (dialog)),
-				       &error);
+	gtk_show_uri (gtk_widget_get_screen(GTK_WIDGET (dialog)),
+		      "ghelp:gnome-pilot", /* FIXME Add section id later */
+		      gtk_get_current_event_time (),
+		      &error);
 
 	if (error)
 	{
@@ -597,28 +642,23 @@ complete_restore (GnomePilotClient* client, const gchar *id,
 	PilotApplet *applet = user_data;
 
 	gtk_widget_destroy (applet->operationDialogWindow);
+	applet->operationDialogWindow = NULL;
 }
 
-static void
-cancel_restore (PilotApplet *self, GnomeDialog *w,gpointer data)
-{
-	g_message (_("cancelling %d"),GPOINTER_TO_INT (data));
-	gnome_pilot_client_remove_request (self->gpc,GPOINTER_TO_INT (data));  
-}
-
-
 static void
 restore_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
 {
 	PilotApplet *applet = user_data;
 	int handle,i;
 	gchar *pilot_name;
-	gint pilot_id;
-	GladeXML *xml;
+	guint pilot_id;
+	GtkBuilder *ui;
 	GtkWidget *dir_entry, *id_entry,*frame;
-	GtkWidget *device_menu, *menu_item,*menu;
+	GtkWidget *device_combo;
+	GtkListStore *list_store;
+	GtkCellRenderer *renderer;
 	GList *list;
-	gchar *buf;
+	gchar *buf = NULL;
 	restore_properties restore_props; 
 
 	
@@ -632,7 +672,8 @@ restore_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
 	}
 
 	if (gnome_pilot_client_get_pilot_base_dir_by_name (applet->gpc,pilot_name,&buf) == GPILOTD_OK) {
-		restore_props.backupdir = g_strdup_printf ("%s/backup/",buf);
+		/* XXX backup conduit allows user to modify the backup directory :( */
+		restore_props.backupdir = g_strdup_printf ("%s",buf);
 		g_free (buf);
 	} else {
 		handle_client_error (applet);
@@ -643,23 +684,23 @@ restore_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
 		return;
 	}
 
-	xml = glade_xml_new (applet->glade_file,"RestoreDialog",NULL);
-	applet->restoreDialog = glade_xml_get_widget (xml,"RestoreDialog");
+	ui = load_ui (applet->ui_file, "RestoreDialog");
+	applet->restoreDialog = get_widget (ui, "RestoreDialog");
 
-	dir_entry = glade_xml_get_widget (xml,"dir_entry");
+	dir_entry = get_widget (ui, "dir_entry");
 
 	gtk_entry_set_text (GTK_ENTRY (dir_entry),restore_props.backupdir);
 	g_free (restore_props.backupdir);
 	restore_props.backupdir=NULL;
 	/* FIXME: do we need to preserve the backupdir somewhere? */
 	
-	frame = glade_xml_get_widget (xml,"main_frame");
+	frame = get_widget (ui,"main_frame");
 	buf = g_strdup_printf (_("Restoring %s"), pilot_name);
 	gtk_frame_set_label (GTK_FRAME (frame), buf);
 	g_free (buf);
 	
 
-	id_entry =  glade_xml_get_widget (xml,"pilotid_entry");
+	id_entry = get_widget (ui, "pilotid_entry");
 	
 	buf = g_strdup_printf ("%d",pilot_id);
 	gtk_entry_set_text (GTK_ENTRY (id_entry),buf);
@@ -669,25 +710,25 @@ restore_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
 	gnome_pilot_client_get_cradles (applet->gpc,&(applet->properties.cradles));
 	list = applet->properties.cradles;
 	
-	device_menu =  glade_xml_get_widget (xml,"device_menu");
-	menu =gtk_menu_new ();
-	
+	device_combo = get_widget (ui, "device_combo");
+	list_store = gtk_list_store_new (1, G_TYPE_STRING);
+	gtk_combo_box_set_model (GTK_COMBO_BOX (device_combo), GTK_TREE_MODEL (list_store));
+	renderer = gtk_cell_renderer_text_new();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (device_combo), renderer, TRUE);
+	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (device_combo), renderer, "text", 0);
+
 	i=0;
 	while (list){
-		menu_item = gtk_menu_item_new_with_label ((gchar*)list->data);
-		gtk_widget_show (menu_item);
-/*
-		gtk_signal_connect (GTK_OBJECT (menu_item),"activate",
-				   GTK_SIGNAL_FUNC (activate_device),
-				   (gchar*)list->data);
-*/
-		gtk_menu_append (GTK_MENU (menu),menu_item);
+		GtkTreeIter iter;
+
+		gtk_list_store_append (list_store, &iter);
+		gtk_list_store_set (list_store, &iter, 0, (gchar*)list->data, -1);
 		list=list->next;
 		i++;
 	}
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (device_menu),menu);	
-	if (i<=1) gtk_widget_set_sensitive (GTK_WIDGET (device_menu),FALSE);
-	else  gtk_widget_set_sensitive (GTK_WIDGET (device_menu),TRUE);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (device_combo), 0);
+	if (i<=1) gtk_widget_set_sensitive (GTK_WIDGET (device_combo),FALSE);
+	else  gtk_widget_set_sensitive (GTK_WIDGET (device_combo),TRUE);
 	
 	if (gtk_dialog_run (GTK_DIALOG (applet->restoreDialog)) == GTK_RESPONSE_OK) {
 		int id;
@@ -696,26 +737,33 @@ restore_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
 		gtk_widget_destroy (applet->restoreDialog);
 		if ( restore_props.backupdir == NULL || 
 		     strlen (restore_props.backupdir)==0) {
-			show_warning_dialog (applet, _("No directory to restore from."));
+			show_dialog (applet, GTK_MESSAGE_WARNING,
+			    _("No directory to restore from."));
 			return;
 		}
 		
 		/* FIXME: how do we specify which device to restore on? */
 		id = gnome_pilot_client_connect__completed_request (applet->gpc, complete_restore, applet);
-		if (gnome_pilot_client_restore (applet->gpc,pilot_name,restore_props.backupdir,GNOME_Pilot_IMMEDIATE,0, &handle) == GPILOTD_OK) {
+		if (gnome_pilot_client_restore (applet->gpc,pilot_name,
+			restore_props.backupdir,
+			GNOME_Pilot_IMMEDIATE,0, &handle) == GPILOTD_OK) {
 			applet->operationDialogWindow = 
-				gnome_message_box_new (_("Press synchronize on the cradle to restore\n" 
-							 " or cancel the operation."),
-						       GNOME_MESSAGE_BOX_GENERIC,
-						       GNOME_STOCK_BUTTON_CANCEL,
-						       NULL);
-			gnome_dialog_button_connect (GNOME_DIALOG (applet->operationDialogWindow),0,
-						     (GCallback) cancel_restore ,GINT_TO_POINTER (handle));
-			gnome_dialog_run_and_close (GNOME_DIALOG (applet->operationDialogWindow));
+			    gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
+				GTK_MESSAGE_OTHER, GTK_BUTTONS_CANCEL, "%s",
+				_("Press synchronize on the cradle to restore\n" 
+				    " or cancel the operation."));
+			gint response = gtk_dialog_run(GTK_DIALOG (applet->operationDialogWindow));
+			if (applet->operationDialogWindow != NULL)
+				gtk_widget_destroy(applet->operationDialogWindow);
+			if (response == GTK_RESPONSE_CANCEL) {
+				g_message (_("cancelling %d"), handle);
+				gnome_pilot_client_remove_request (applet->gpc, handle);
+			}
 		} else {
-			show_warning_dialog (applet,_("Restore request failed"));
+			show_dialog (applet, GTK_MESSAGE_WARNING,
+			    _("Restore request failed"));
 		}
-		gtk_signal_disconnect (applet->gpc, id);		
+		g_signal_handler_disconnect (applet->gpc, id);		
 	} else {
 		gtk_widget_destroy (applet->restoreDialog);
 	}	
@@ -749,9 +797,15 @@ static void
 restart_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
 {
 	PilotApplet *applet = user_data;
+	GtkWidget *dialog;
 
 	if (applet->curstate == SYNCING) {
-		if ( gnome_dialog_run_and_close (GNOME_DIALOG (gnome_question_dialog (_("PDA sync is currently in progress.\nAre you sure you want to restart daemon?"),NULL,NULL))) !=0 ) {
+		dialog = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL,
+		    GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, "%s",
+		    _("PDA sync is currently in progress.\nAre you sure you want to restart daemon?"));
+		gint response = gtk_dialog_run(GTK_DIALOG(dialog));
+		gtk_widget_destroy(dialog);
+		if (response != GTK_RESPONSE_YES) {
 			return;
 		}
 		if (applet->progressDialog!=NULL) {
@@ -759,10 +813,12 @@ restart_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
 		}
 	}
 	applet->curstate = INITIALISING;
+	g_message ("state = INITIALISING");
+
 	gnome_pilot_client_restart_daemon (applet->gpc);
-	gtk_tooltips_set_tip (applet->tooltips, GTK_WIDGET (applet->applet),
-			      _("Trying to connect to the GnomePilot Daemon"), NULL);
-	applet->timeout_handler_id = gtk_timeout_add (1000,(GtkFunction)timeout,applet);
+	gtk_widget_set_tooltip_text(GTK_WIDGET(applet->applet), 
+	    _("Trying to connect to the GnomePilot Daemon"));
+	applet->timeout_handler_id = g_timeout_add (1000,(GSourceFunc)timeout,applet);
 
 	return;
 }
@@ -777,7 +833,8 @@ log_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
 		gtk_widget_set_sensitive (applet->cancel_button,TRUE);
 		gtk_widget_show_all (applet->progressDialog);
 	} else {
-		show_message_dialog (applet, _("There's no last sync on record."));
+		show_dialog (applet, GTK_MESSAGE_INFO,
+		    _("There's no last sync on record."));
 	}
 }
 
@@ -845,21 +902,23 @@ gpilotd_daemon_pause (GnomePilotClient *client,
 	if (on_off) {
 		if (applet->curstate == WAITING) {
 			applet->curstate = PAUSED;
-			gtk_tooltips_set_tip (applet->tooltips, GTK_WIDGET (applet->applet),_("Daemon paused..."), NULL);
+			gtk_widget_set_tooltip_text(GTK_WIDGET(applet->applet), 
+			    _("Daemon paused..."));
+			g_message ("state = PAUSED");
 		}
 		else
 			handle_client_error (applet);
 	}
 	else {
 		applet->curstate = WAITING;
-		gtk_tooltips_set_tip (applet->tooltips, GTK_WIDGET (applet->applet), _("Ready to synchronize"), NULL);
+		gtk_widget_set_tooltip_text(GTK_WIDGET(applet->applet), 
+		    _("Ready to synchronize"));
+		g_message ("state = READY");
 	}
 
 	install_popup_menu (applet, on_off);
 
 	pilot_draw (applet);
-	
-	g_message ("paused");
 }
 
 static void 
@@ -961,17 +1020,16 @@ static gboolean
 timeout (PilotApplet *self)
 {
 	if (self->curstate == INITIALISING) {
-		g_message ("state = INITIALISING");
 		pilot_draw (self);
 		
 		if (gnome_pilot_client_connect_to_daemon (self->gpc) == GPILOTD_OK) {
 			self->curstate = CONNECTING_TO_DAEMON;
+			g_message ("state = CONNECTING_TO_DAEMON");
 			pilot_draw (self);
 		} 
 	}
 	
 	if (self->curstate == CONNECTING_TO_DAEMON) {
-		g_message ("state = CONNECTING_TO_DAEMON");
 		
 		if (self->properties.pilot_ids) {
 			GList *tmp =self->properties.pilot_ids;
@@ -985,31 +1043,23 @@ timeout (PilotApplet *self)
 		self->properties.pilot_ids = get_pilot_ids_from_gpilotd (self);
 
 		if (self->properties.pilot_ids==NULL){
-			gtk_tooltips_set_tip (self->tooltips,
-					      GTK_WIDGET(self->applet),
-					      _("Not connected. Restart daemon to reconnect"),
-					      NULL);
+			gtk_widget_set_tooltip_text(GTK_WIDGET(self->applet), 
+				_("Not connected. Restart daemon to reconnect"));
 			if (self->druid_already_launched == FALSE) {
 				self->druid_already_launched = TRUE;
 				pilot_execute_program (self, GPILOTD_DRUID);
 			}
 
-			self->curstate=INITIALISING;
+			self->curstate = INITIALISING;
+			g_message ("state = INITIALISING");
 			pilot_draw (self);
 			/* FIXME: add gpilot_monitor_state_change () */
 		} else {
-			gnome_pilot_client_monitor_on_all_pilots (self->gpc);
-			
-			gnome_pilot_client_notify_on (self->gpc,GNOME_Pilot_NOTIFY_CONNECT);
-			gnome_pilot_client_notify_on (self->gpc,GNOME_Pilot_NOTIFY_CONDUIT);
-			gnome_pilot_client_notify_on (self->gpc,GNOME_Pilot_NOTIFY_DISCONNECT);
-			
-			gtk_tooltips_set_tip (self->tooltips, 
-					      GTK_WIDGET (self->applet),
-					      _("Ready to synchronize"),
-					      NULL);
+			gtk_widget_set_tooltip_text(GTK_WIDGET(self->applet), 
+				_("Ready to synchronize"));
 			
 			self->curstate = WAITING;
+			g_message ("state = READY");
 			pilot_draw (self);
 		}
 	} 
@@ -1019,6 +1069,7 @@ timeout (PilotApplet *self)
 		/* this will happen once a sec */
 		if (gnome_pilot_client_noop (self->gpc) == GPILOTD_ERR_NOT_CONNECTED) {
 			self->curstate = INITIALISING;
+			g_message ("state = INITIALISING");
 		}
 		break;
 	case SYNCING: 
@@ -1032,50 +1083,23 @@ timeout (PilotApplet *self)
 }
 
 static void 
-show_error_dialog (PilotApplet *self, gchar *mesg,...) 
+show_dialog (PilotApplet *self, GtkMessageType type, gchar *mesg,...) 
 {
 	char *tmp;
 	va_list ap;
 
 	va_start (ap,mesg);
 	tmp = g_strdup_vprintf (mesg,ap);
-	self->dialogWindow = gnome_message_box_new (tmp,GNOME_MESSAGE_BOX_ERROR,
-						    GNOME_STOCK_BUTTON_OK,NULL);
-	gnome_dialog_run_and_close (GNOME_DIALOG (self->dialogWindow));
+
+	self->dialogWindow = gtk_message_dialog_new(NULL, GTK_DIALOG_MODAL,
+	    type, GTK_BUTTONS_OK, "%s", tmp);
+
+	gtk_dialog_run (GTK_DIALOG (self->dialogWindow));
+	gtk_widget_destroy (self->dialogWindow);
 	g_free (tmp);
 	va_end (ap);
 }
 
-static void 
-show_warning_dialog (PilotApplet *self, gchar *mesg,...) 
-{
-	char *tmp;
-	va_list ap;
-
-	va_start (ap,mesg);
-	tmp = g_strdup_vprintf (mesg,ap);
-	self->dialogWindow = gnome_message_box_new (tmp,GNOME_MESSAGE_BOX_WARNING,
-						    GNOME_STOCK_BUTTON_OK,NULL);
-	gnome_dialog_run_and_close (GNOME_DIALOG (self->dialogWindow));
-	g_free (tmp);
-	va_end (ap);
-}
-
-
-static void 
-show_message_dialog (PilotApplet *self, char *mesg,...)
-{
-	char *tmp;
-	va_list ap;
-
-	va_start (ap,mesg);
-	tmp = g_strdup_vprintf (mesg,ap);
-	self->dialogWindow = gnome_message_box_new (tmp,GNOME_MESSAGE_BOX_GENERIC,
-						    GNOME_STOCK_BUTTON_OK,NULL);
-	gnome_dialog_run_and_close (GNOME_DIALOG (self->dialogWindow));
-	g_free (tmp);
-	va_end (ap);
-}
 
 static void
 load_properties (PilotApplet *self)
@@ -1109,13 +1133,18 @@ save_properties (PilotApplet *self)
 				     "pop_ups",
 				     self->properties.popups,
 				     NULL);
-	/* gnome_config_set_int ("text_limit",properties.text_limit); */
 }
 
 static void
-activate_pilot_menu (PilotApplet *self, GtkMenuItem *widget, gpointer data)
+activate_pilot_menu (GtkComboBox *widget, gpointer data)
 {
-	gtk_object_set_data (GTK_OBJECT (self->chooseDialog),"pilot",data);	
+	PilotApplet *applet = PILOT_APPLET (data);
+	gchar *label;
+	GtkTreeIter iter;
+
+	gtk_combo_box_get_active_iter(widget, &iter);
+	gtk_tree_model_get (gtk_combo_box_get_model (widget), &iter, 0, &label, -1);
+	g_object_set_data (G_OBJECT (applet->chooseDialog), "pilot", (gpointer)label);
 }
 
 static gchar*
@@ -1128,37 +1157,51 @@ pick_pilot (PilotApplet *self)
 			pilot = (gchar*)self->properties.pilot_ids->data;
 		} else {
 			GList *tmp;
-			GtkWidget *optionMenu,*menuItem,*menu;
+			GtkWidget *combo;
+			GtkListStore *list_store;
+			GtkCellRenderer *renderer;
+
 			if (self->chooseDialog == NULL) {
-				GladeXML * xml;
+				GtkBuilder * ui;
+
+				ui = load_ui (self->ui_file,"ChoosePilot");
+				self->chooseDialog = get_widget (ui,"ChoosePilot");
+				combo = get_widget (ui, "pilot_combo");
+				g_object_set_data (G_OBJECT (self->chooseDialog),"pilot_combo", combo);
+
 
-				xml = glade_xml_new (self->glade_file,"ChoosePilot",NULL);
-				self->chooseDialog = glade_xml_get_widget (xml,"ChoosePilot");
-				optionMenu=glade_xml_get_widget (xml,"pilot_menu");
-				gtk_object_set_data (GTK_OBJECT (self->chooseDialog),"pilot_menu",optionMenu);
 			} else {
-				optionMenu=gtk_object_get_data (GTK_OBJECT (self->chooseDialog),"pilot_menu");
+				combo = g_object_get_data (G_OBJECT (self->chooseDialog), "pilot_combo");
 			}
-			menu = gtk_menu_new ();
-	
+
+			list_store = gtk_list_store_new (1, G_TYPE_STRING);
+			gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (list_store));
+			gtk_cell_layout_clear(GTK_CELL_LAYOUT(combo));
+			renderer = gtk_cell_renderer_text_new();
+			gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (combo), renderer, TRUE);
+			gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (combo), renderer, "text", 0);
 			tmp=self->properties.pilot_ids;
 			while (tmp!=NULL){
-				menuItem = gtk_menu_item_new_with_label ((gchar*)tmp->data);
-				gtk_widget_show (menuItem);
-				gtk_signal_connect (GTK_OBJECT (menuItem),"activate",
-						   GTK_SIGNAL_FUNC (activate_pilot_menu),
-						   tmp->data);
-				gtk_menu_append (GTK_MENU (menu),menuItem);
+				GtkTreeIter iter;
+
+				gtk_list_store_append (list_store, &iter);
+				gtk_list_store_set (list_store, &iter, 0, (gchar*)tmp->data, -1);
 				tmp=tmp->next;
 			}
-			gtk_option_menu_set_menu (GTK_OPTION_MENU (optionMenu),menu);
-			gtk_option_menu_set_history (GTK_OPTION_MENU (optionMenu),0);
-			gtk_object_set_data (GTK_OBJECT (self->chooseDialog),"pilot",self->properties.pilot_ids->data);	
-			if (gnome_dialog_run_and_close (GNOME_DIALOG (self->chooseDialog))==0) {
-				pilot=(gchar *)gtk_object_get_data (GTK_OBJECT (self->chooseDialog),"pilot");
+
+
+			g_signal_connect (G_OBJECT (combo), "changed",
+			                  G_CALLBACK (activate_pilot_menu),
+			                  self);
+
+			gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
+			g_object_set_data (G_OBJECT (self->chooseDialog),"pilot",self->properties.pilot_ids->data);	
+			if (gtk_dialog_run(GTK_DIALOG (self->chooseDialog))== 0) {
+				pilot=(gchar *)g_object_get_data (G_OBJECT (self->chooseDialog),"pilot");
 			} else {
 				pilot=NULL;
 			}
+			gtk_widget_hide(self->chooseDialog);
 		}
 	}
 
@@ -1171,7 +1214,8 @@ pilot_execute_program (PilotApplet *self, const gchar *str)
 	g_return_if_fail (str != NULL);
 
 	if (!g_spawn_command_line_async (str, NULL))
-		show_warning_dialog (self, _("Execution of %s failed"),str);
+		show_dialog (self, GTK_MESSAGE_WARNING,
+		    _("Execution of %s failed"),str);
 }
 
 static gint 
@@ -1287,7 +1331,7 @@ dnd_drop_internal (GtkWidget        *widget,
 	switch (info)
 	{
 	case TARGET_URI_LIST:
-		names = extract_uris (selection_data->data);
+		names = extract_uris ((gchar *) selection_data->data);
 		for (idx=0; names[idx]; idx++) {
 			/*
 			  if (strstr (file_type (ptr),"text")) {
@@ -1317,6 +1361,8 @@ applet_destroy (GtkWidget *applet, PilotApplet *self)
 {
 	g_message (_("destroy gpilot-applet"));
 
+	g_source_remove(self->timeout_handler_id);
+
 	/* XXX free other stuff */
 	g_free (self);
 }
@@ -1324,48 +1370,40 @@ applet_destroy (GtkWidget *applet, PilotApplet *self)
 static void
 create_pilot_widgets (GtkWidget *widget, PilotApplet *self) 
 { 
-	GtkStyle *style; 
-	int i; 
-
 	static GtkTargetEntry drop_types [] = {  
 		{ "text/uri-list", 0, TARGET_URI_LIST }, 
 	}; 
 	static gint n_drop_types = sizeof (drop_types) / sizeof (drop_types[0]); 
 
-	style = gtk_widget_get_style (widget); 
-
-	self->tooltips = gtk_tooltips_new ();
-
-	gtk_tooltips_set_tip (GTK_TOOLTIPS (self->tooltips), widget,
-			      _("Trying to connect to " 
-				"the GnomePilot Daemon"),
-			      NULL);
+	gtk_widget_set_tooltip_text(widget,
+		_("Trying to connect to the GnomePilot Daemon"));
 
 	self->c_progress = GPILOT_APPLET_PROGRESS (gpilot_applet_progress_new ()); 
 
 	self->curstate = INITIALISING; 
+	g_message ("state = INITIALISING");
 
-	for (i = 0; i < sizeof (pixmaps)/sizeof (pixmaps[0]); i++) 
+	/*	for (i = 0; i < sizeof (pixmaps)/sizeof (pixmaps[0]); i++) 
 		pixmaps[i] = gnome_program_locate_file(
 		    NULL, GNOME_FILE_DOMAIN_PIXMAP, pixmaps[i], TRUE, NULL);
-
+	*/
 	self->image = gtk_image_new_from_file (pixmaps[self->curstate]); 
 
-	gtk_signal_connect (GTK_OBJECT (widget), "button-press-event", 
-			    GTK_SIGNAL_FUNC (pilot_clicked_cb), self); 
+	g_signal_connect   (GTK_OBJECT (widget), "button-press-event", 
+			    G_CALLBACK (pilot_clicked_cb), self); 
 
 
 	gtk_widget_show (self->image);   
 
 	gtk_container_add (GTK_CONTAINER (widget), self->image);
 
-	self->timeout_handler_id = gtk_timeout_add (1000,(GtkFunction)timeout,self); 
+	self->timeout_handler_id = g_timeout_add (1000,(GSourceFunc)timeout,self); 
 
-	gtk_signal_connect (GTK_OBJECT (widget),"destroy", 
-			    GTK_SIGNAL_FUNC (applet_destroy),self); 
+	g_signal_connect   (GTK_OBJECT (widget),"destroy", 
+			    G_CALLBACK (applet_destroy),self); 
 
-	gtk_signal_connect (GTK_OBJECT (widget),"change_background", 
-			    GTK_SIGNAL_FUNC (applet_back_change),self); 
+	g_signal_connect   (GTK_OBJECT (widget),"change_background", 
+			    G_CALLBACK (applet_back_change),self); 
 
 	/* FIXME */
 	/* XXX change_orient */
@@ -1378,9 +1416,9 @@ create_pilot_widgets (GtkWidget *widget, PilotApplet *self)
 			   GDK_ACTION_COPY); 
 
 
-	gtk_signal_connect (GTK_OBJECT (self->image), 
+	g_signal_connect   (GTK_OBJECT (self->image), 
 			    "drag_data_received", 
-			    GTK_SIGNAL_FUNC (dnd_drop_internal), 
+			    G_CALLBACK (dnd_drop_internal), 
 			    self); 
 
 	install_popup_menu (self, FALSE);
@@ -1393,14 +1431,15 @@ pilot_applet_fill (PanelApplet *applet)
 
 	self->applet = applet;
 
-	/* initialize glade */
-	glade_gnome_init ();
-	self->glade_file="./pilot-applet.glade";
-	if (!g_file_exists (self->glade_file)) {
-		self->glade_file = g_concat_dir_and_file (GLADEDATADIR, "pilot-applet.glade");
+	self->ui_file="./pilot-applet.ui";
+	if (!g_file_test (self->ui_file, G_FILE_TEST_EXISTS)) {
+		self->ui_file = g_build_filename (UIDATADIR,
+						     "pilot-applet.ui",
+						     NULL);
 	}
-	if (!g_file_exists (self->glade_file)) {
-		show_error_dialog (self, _("Cannot find pilot-applet.glade"));
+	if (!g_file_test (self->ui_file, G_FILE_TEST_EXISTS)) {
+		show_dialog (self, GTK_MESSAGE_ERROR,
+		    "Cannot find %s", self->ui_file); /* FIXME: Make translatable after string freeze */
 		return -1;
 	}
 
