@@ -28,7 +28,6 @@
  */
 
 #include <sys/stat.h>
-#include <glade/glade.h>
 #include "pilot.h"
 #include "util.h"
 #include "gnome-pilot-pdialog.h"
@@ -42,7 +41,7 @@ static GObjectClass *parent_class = NULL;
 
 struct _GnomePilotCappletPrivate 
 {
-	GladeXML *xml;
+	GtkBuilder *ui;
 
 	GnomePilotClient *gpc;
 	gint handle;
@@ -71,7 +70,7 @@ struct _GnomePilotCappletPrivate
 	GtkWidget *devices_popup;
 
 	GtkObject *pdialog;
-	GtkWidget *pilots_menu;
+	GtkWidget *pilots_combo;
 	GtkWidget *pilots_username;
 	GtkWidget *conduit_treeview;
 	GtkTreeModel *conduit_model;
@@ -108,6 +107,10 @@ static void gpcap_devices_delete (GtkWidget *widget, gpointer user_data);
 static gboolean gpcap_devices_popup (GtkTreeView *treeview, GdkEventButton *event, gpointer user_data);
 static void gpcap_devices_selection_changed (GtkTreeSelection *selection, gpointer user_data);
 
+static void gpcap_create_pilots_treeview (GnomePilotCappletPrivate *priv);
+static void gpcap_create_devices_treeview (GnomePilotCappletPrivate *priv);
+static void gpcap_create_conduit_treeview (GnomePilotCappletPrivate *priv);
+
 static void gpcap_conduits_choose_pilot (GtkWidget *widget, gpointer user_data);
 static void gpcap_conduits_enable (GtkWidget *widget, gpointer user_data);
 static void gpcap_conduits_disable (GtkWidget *widget, gpointer user_data);
@@ -159,7 +162,13 @@ static void
 init (GnomePilotCapplet *gpcap)
 {
 	GnomePilotCappletPrivate *priv;
-	
+	guint error;
+ 	gchar *objects[] = {"timeout_adjustment",
+			    "device_speed_store",
+			    "pilot_charset_store",
+			    "CappletMain",
+ 			    NULL};
+
 	priv = g_new0 (GnomePilotCappletPrivate, 1);
 
 	gpcap->priv = priv;
@@ -169,17 +178,21 @@ init (GnomePilotCapplet *gpcap)
 	priv->state = dupPilotState (priv->orig_state);
 
 	/* Gui stuff */
-	priv->xml = glade_xml_new ("gpilotd-capplet.glade", "CappletMain", NULL);
-	if (!priv->xml) {
-		priv->xml = glade_xml_new (GLADEDATADIR "/gpilotd-capplet.glade", "CappletMain", NULL);
-		if (!priv->xml) {
-			g_message ("gnome-pilot-capplet init(): Could not load the Glade XML file!");
+	priv->ui = gtk_builder_new ();
+	error = gtk_builder_add_objects_from_file (priv->ui, "gpilotd-capplet.ui", objects, NULL);
+	if (error == 0) {
+		error = gtk_builder_add_objects_from_file (priv->ui, UIDATADIR "/gpilotd-capplet.ui", objects, NULL);
+		if (error == 0) {
+			g_message ("gnome-pilot-capplet init(): Could not load the GtkBuilder UI file!");
 			goto error;
 		}
 	}
+	gpcap_create_pilots_treeview (priv);
+	gpcap_create_devices_treeview (priv);
+	gpcap_create_conduit_treeview (priv);
 	
 	if (!get_widgets (gpcap)) {
-		g_message ("gnome-pilot-capplet init(): Could not find all widgets in the XML file!");
+		g_message ("gnome-pilot-capplet init(): Could not find all widgets in the UI file!");
 		goto error;
 	}
 	
@@ -210,7 +223,7 @@ get_widgets (GnomePilotCapplet *gpcap)
 
 	priv = gpcap->priv;
 
-#define GW(name) glade_xml_get_widget (priv->xml, name)
+#define GW(name) GTK_WIDGET (gtk_builder_get_object (priv->ui, name))
 
 	gtk_window_set_title (GTK_WINDOW (gpcap), _("gnome-pilot Settings"));
 	gtk_dialog_set_has_separator (GTK_DIALOG (gpcap), FALSE);
@@ -225,24 +238,24 @@ get_widgets (GnomePilotCapplet *gpcap)
 		gtk_container_add (GTK_CONTAINER (GTK_DIALOG (gpcap)->vbox), priv->notebook);
 
 	w = GW ("pilots_treeview");
-	priv->pilots_treeview = gtk_object_get_data (GTK_OBJECT (w), "treeview");
-	priv->pilots_model = gtk_object_get_data (GTK_OBJECT (w), "model");
+	priv->pilots_treeview = g_object_get_data (G_OBJECT (w), "treeview");
+	priv->pilots_model = g_object_get_data (G_OBJECT (w), "model");
 	priv->pilots_add = GW ("pilots_add_button");
 	priv->pilots_edit = GW ("pilots_edit_button");
 	priv->pilots_delete = GW ("pilots_delete_button");
 
 	w = GW ("devices_treeview");
-	priv->devices_treeview = gtk_object_get_data (GTK_OBJECT (w), "treeview");
-	priv->devices_model = gtk_object_get_data (GTK_OBJECT (w), "model");
+	priv->devices_treeview = g_object_get_data (G_OBJECT (w), "treeview");
+	priv->devices_model = g_object_get_data (G_OBJECT (w), "model");
 	priv->devices_add = GW ("devices_add_button");
 	priv->devices_edit = GW ("devices_edit_button");
 	priv->devices_delete = GW ("devices_delete_button");
 
-	priv->pilots_menu = GW ("pilots_menu");
+	priv->pilots_combo = GW ("pilots_combo");
 	priv->pilots_username = GW ("username_label");	
 	w = GW ("conduit_treeview");
-	priv->conduit_treeview = gtk_object_get_data (GTK_OBJECT (w), "treeview");
-	priv->conduit_model = gtk_object_get_data (GTK_OBJECT (w), "model");
+	priv->conduit_treeview = g_object_get_data (G_OBJECT (w), "treeview");
+	priv->conduit_model = g_object_get_data (G_OBJECT (w), "model");
 	priv->conduit_enable = GW ("conduit_enable_button");
 	priv->conduit_disable = GW ("conduit_disable_button");
 	priv->conduit_settings = GW ("conduit_settings_button");
@@ -258,7 +271,7 @@ get_widgets (GnomePilotCapplet *gpcap)
 		&& priv->devices_add
 		&& priv->devices_edit
 		&& priv->devices_delete
-		&& priv->pilots_menu
+		&& priv->pilots_combo
 		&& priv->conduit_treeview
 		&& priv->conduit_enable
 		&& priv->conduit_disable
@@ -274,32 +287,32 @@ init_widgets (GnomePilotCapplet *gpcap)
 	priv = gpcap->priv;
 
 	/* Button signals */
-	gtk_signal_connect (GTK_OBJECT (priv->pilots_add), "clicked",
-			    GTK_SIGNAL_FUNC (gpcap_pilots_add), gpcap);
+	g_signal_connect   (GTK_OBJECT (priv->pilots_add), "clicked",
+			    G_CALLBACK (gpcap_pilots_add), gpcap);
 
-	gtk_signal_connect (GTK_OBJECT (priv->pilots_edit), "clicked",
-			    GTK_SIGNAL_FUNC (gpcap_pilots_edit), gpcap);
+	g_signal_connect   (GTK_OBJECT (priv->pilots_edit), "clicked",
+			    G_CALLBACK (gpcap_pilots_edit), gpcap);
 
-	gtk_signal_connect (GTK_OBJECT (priv->pilots_delete), "clicked",
-			    GTK_SIGNAL_FUNC (gpcap_pilots_delete), gpcap);
+	g_signal_connect   (GTK_OBJECT (priv->pilots_delete), "clicked",
+			    G_CALLBACK (gpcap_pilots_delete), gpcap);
 
-	gtk_signal_connect (GTK_OBJECT (priv->devices_add), "clicked",
-			    GTK_SIGNAL_FUNC (gpcap_devices_add), gpcap);
+	g_signal_connect   (GTK_OBJECT (priv->devices_add), "clicked",
+			    G_CALLBACK (gpcap_devices_add), gpcap);
 
-	gtk_signal_connect (GTK_OBJECT (priv->devices_edit), "clicked",
-			    GTK_SIGNAL_FUNC (gpcap_devices_edit), gpcap);
+	g_signal_connect   (GTK_OBJECT (priv->devices_edit), "clicked",
+			    G_CALLBACK (gpcap_devices_edit), gpcap);
 
-	gtk_signal_connect (GTK_OBJECT (priv->devices_delete), "clicked",
-			    GTK_SIGNAL_FUNC (gpcap_devices_delete), gpcap);
+	g_signal_connect   (GTK_OBJECT (priv->devices_delete), "clicked",
+			    G_CALLBACK (gpcap_devices_delete), gpcap);
 
-	gtk_signal_connect (GTK_OBJECT (priv->conduit_enable), "clicked",
-			    GTK_SIGNAL_FUNC (gpcap_conduits_enable), gpcap);
+	g_signal_connect   (GTK_OBJECT (priv->conduit_enable), "clicked",
+			    G_CALLBACK (gpcap_conduits_enable), gpcap);
 
-	gtk_signal_connect (GTK_OBJECT (priv->conduit_disable), "clicked",
-			    GTK_SIGNAL_FUNC (gpcap_conduits_disable), gpcap);
+	g_signal_connect   (GTK_OBJECT (priv->conduit_disable), "clicked",
+			    G_CALLBACK (gpcap_conduits_disable), gpcap);
 
-	gtk_signal_connect (GTK_OBJECT (priv->conduit_settings), "clicked",
-			    GTK_SIGNAL_FUNC (gpcap_conduits_settings), gpcap);
+	g_signal_connect   (GTK_OBJECT (priv->conduit_settings), "clicked",
+			    G_CALLBACK (gpcap_conduits_settings), gpcap);
 
 	/* Row selection signals */
 	g_signal_connect (gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->pilots_treeview)), "changed",
@@ -312,12 +325,12 @@ init_widgets (GnomePilotCapplet *gpcap)
 			  G_CALLBACK (gpcap_conduits_selection_changed), gpcap);
 
 	/* Popup menu signals */
-	gtk_signal_connect (GTK_OBJECT (priv->pilots_treeview), "button_press_event",
-			    GTK_SIGNAL_FUNC (gpcap_pilots_popup), gpcap);
-	gtk_signal_connect (GTK_OBJECT (priv->devices_treeview), "button_press_event",
-			    GTK_SIGNAL_FUNC (gpcap_devices_popup), gpcap);
-	gtk_signal_connect (GTK_OBJECT (priv->conduit_treeview), "button_press_event",
-			    GTK_SIGNAL_FUNC (gpcap_conduits_popup), gpcap);
+	g_signal_connect   (GTK_OBJECT (priv->pilots_treeview), "button_press_event",
+			    G_CALLBACK (gpcap_pilots_popup), gpcap);
+	g_signal_connect   (GTK_OBJECT (priv->devices_treeview), "button_press_event",
+			    G_CALLBACK (gpcap_devices_popup), gpcap);
+	g_signal_connect   (GTK_OBJECT (priv->conduit_treeview), "button_press_event",
+			    G_CALLBACK (gpcap_conduits_popup), gpcap);
 
 	gtk_widget_show_all (priv->notebook);
 }
@@ -360,17 +373,15 @@ fill_pilots_treeview (GnomePilotCapplet *gpcap)
 	}	
 }
 
-GtkWidget* gnome_pilot_capplet_create_pilots_treeview (char *name, char *string1, char *string2, int num1, int num2);
-
-GtkWidget*
-gnome_pilot_capplet_create_pilots_treeview (char *name, char *string1, char *string2, int num1, int num2)
+static void
+gpcap_create_pilots_treeview (GnomePilotCappletPrivate *priv)
 {
-	GtkWidget *treeview, *scrolled;
+	GtkWidget *treeview;
+	GtkWidget *scrolled = GTK_WIDGET (gtk_builder_get_object (priv->ui, "pilots_treeview"));
 	GtkTreeSelection *selection;
 	GtkCellRenderer *renderer;
 	GtkListStore *model;
 
-	scrolled = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
 					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
@@ -398,8 +409,6 @@ gnome_pilot_capplet_create_pilots_treeview (char *name, char *string1, char *str
 
 	gtk_widget_show (scrolled);
 	gtk_widget_show (treeview);
-
-	return scrolled;
 }
 
 static void
@@ -440,17 +449,15 @@ fill_devices_treeview (GnomePilotCapplet *gpcap)
 	}	
 }
 
-GtkWidget *gnome_pilot_capplet_create_devices_treeview (char *name, char *string1, char *string2, int num1, int num2);
-
-GtkWidget*
-gnome_pilot_capplet_create_devices_treeview (char *name, char *string1, char *string2, int num1, int num2)
+static void
+gpcap_create_devices_treeview (GnomePilotCappletPrivate *priv)
 {
-	GtkWidget *treeview, *scrolled;
+	GtkWidget *treeview;
+	GtkWidget *scrolled = GTK_WIDGET (gtk_builder_get_object (priv->ui, "devices_treeview"));
 	GtkTreeSelection *selection;
 	GtkCellRenderer *renderer;
 	GtkListStore *model;
 
-	scrolled = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
 					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
@@ -476,8 +483,6 @@ gnome_pilot_capplet_create_devices_treeview (char *name, char *string1, char *st
 
 	gtk_widget_show (scrolled);
 	gtk_widget_show (treeview);
-
-	return scrolled;
 }
 
 static void
@@ -548,17 +553,15 @@ set_conduit_pilot (GnomePilotCapplet *gpcap, GPilotPilot *pilot)
 	check_conduits_buttons (gpcap);
 }
 
-GtkWidget *gnome_pilot_capplet_create_conduit_treeview (char *name, char *string1, char *string2, int num1, int num2);
-
-GtkWidget*
-gnome_pilot_capplet_create_conduit_treeview (char *name, char *string1, char *string2, int num1, int num2)
+static void
+gpcap_create_conduit_treeview (GnomePilotCappletPrivate *priv)
 {
-	GtkWidget *treeview, *scrolled;
+	GtkWidget *treeview;
+	GtkWidget *scrolled = GTK_WIDGET (gtk_builder_get_object (priv->ui, "conduit_treeview"));
 	GtkTreeSelection *selection;
 	GtkCellRenderer *renderer;
 	GtkListStore *model;
 
-	scrolled = gtk_scrolled_window_new (NULL, NULL);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
 					GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
@@ -584,40 +587,44 @@ gnome_pilot_capplet_create_conduit_treeview (char *name, char *string1, char *st
 
 	gtk_widget_show (scrolled);
 	gtk_widget_show (treeview);
-
-	return scrolled;
 }
 
 static void
-fill_pilots_menu (GnomePilotCapplet *gpcap) 
+fill_pilots_combo (GnomePilotCapplet *gpcap) 
 {
-	GnomePilotCappletPrivate *priv;
-	GtkWidget *menu, *menu_item;
-	GList *tmp;
-	GPilotPilot *pilot = NULL;
-	
-	priv = gpcap->priv;
-	
-	menu = gtk_menu_new ();
-	
-	tmp = priv->state->pilots;
-	while (tmp != NULL) {
-		if (pilot == NULL)
-			pilot = tmp->data;
-		
-		menu_item = gtk_menu_item_new_with_label (((GPilotPilot*)tmp->data)->name);
-		gtk_widget_show (menu_item);
-		gtk_object_set_data (GTK_OBJECT (menu_item), "pilot", tmp->data);
-		gtk_signal_connect (GTK_OBJECT(menu_item),"activate",
-				    GTK_SIGNAL_FUNC (gpcap_conduits_choose_pilot),
-				    gpcap);
-		gtk_menu_append (GTK_MENU (menu), menu_item);
+        GnomePilotCappletPrivate *priv;
+        GList *tmp;
+        GPilotPilot *pilot = NULL;
+        GtkListStore *store;
+        GtkTreeIter iter;
+        
+        priv = gpcap->priv;
 
-		tmp = tmp->next;
-	}
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (priv->pilots_menu), menu);
-	gtk_option_menu_set_history (GTK_OPTION_MENU (priv->pilots_menu), 0);
-	set_conduit_pilot (gpcap, pilot);
+
+        store = gtk_list_store_new(1, G_TYPE_STRING);
+        
+        tmp = priv->state->pilots;
+        while (tmp != NULL) {
+                if (pilot == NULL)
+                        pilot = tmp->data;
+                
+                gtk_list_store_append(store, &iter);
+                gtk_list_store_set (store, &iter, 0, ((GPilotPilot*)tmp->data)->name, -1);
+                tmp = tmp->next;
+        }
+
+	g_signal_connect   (GTK_OBJECT(priv->pilots_combo),"changed",
+		    G_CALLBACK (gpcap_conduits_choose_pilot),
+		    gpcap);
+	gtk_combo_box_set_model (GTK_COMBO_BOX (priv->pilots_combo), GTK_TREE_MODEL(store));
+	gtk_cell_layout_clear(GTK_CELL_LAYOUT(priv->pilots_combo));
+	GtkCellRenderer *renderer = gtk_cell_renderer_text_new();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (priv->pilots_combo),
+	    renderer, TRUE);
+	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (priv->pilots_combo),
+	    renderer, "text", 0);        
+	gtk_combo_box_set_active (GTK_COMBO_BOX (priv->pilots_combo), 0);
+        set_conduit_pilot (gpcap, pilot);
 }
 
 static void
@@ -636,7 +643,7 @@ fill_widgets (GnomePilotCapplet *gpcap)
 	check_devices_buttons (gpcap);
 
 	/* Conduits page */
-	fill_pilots_menu (gpcap);
+	fill_pilots_combo (gpcap);
 }
 
 void
@@ -725,7 +732,7 @@ gpcap_pilots_add (GtkWidget *widget, gpointer user_data)
 		gtk_tree_selection_select_iter (gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->pilots_treeview)),
 						&iter);
 		
-		fill_pilots_menu (gpcap);
+		fill_pilots_combo (gpcap);
 		
 		gpcap_save_state (gpcap);
 	}
@@ -759,7 +766,7 @@ gpcap_pilots_edit (GtkWidget *widget, gpointer user_data)
 				    2, pilot->pilot_username,
 				    -1);
 			
-		fill_pilots_menu (gpcap);
+		fill_pilots_combo (gpcap);
 		
 		gpcap_save_state (gpcap);
 	}
@@ -787,7 +794,7 @@ gpcap_pilots_delete (GtkWidget *widget, gpointer user_data)
 				       &iter);
 		priv->state->pilots = g_list_remove (priv->state->pilots, pilot);
 		
-		fill_pilots_menu (gpcap);
+		fill_pilots_combo (gpcap);
 		
 		gpcap_save_state (gpcap);
 	}
@@ -803,21 +810,39 @@ gpcap_pilots_popup (GtkTreeView *treeview, GdkEventButton *event, gpointer user_
 	GnomePilotCapplet *gpcap = GNOME_PILOT_CAPPLET (user_data);
 	GnomePilotCappletPrivate *priv;
 
-	GnomeUIInfo popup [] = {
-		GNOMEUIINFO_ITEM_DATA (N_("_Edit this PDA..."),
-				       N_("Edit the currently selected PDA"),
-				       gpcap_pilots_edit, gpcap, NULL),
-		GNOMEUIINFO_ITEM_DATA (N_("_Delete this PDA"),
-				       N_("Delete the currently selected PDA"),
-				       gpcap_pilots_delete, gpcap, NULL),
-		GNOMEUIINFO_END
+	GtkActionEntry entries[] = {
+		{ "Edit", NULL, N_("_Edit this PDA..."), NULL,
+		  N_("Edit the currently selected PDA"), G_CALLBACK(gpcap_pilots_edit)},
+		{ "Delete", NULL, N_("_Delete this PDA"), NULL,
+		  N_("Delete the currently selected PDA"), G_CALLBACK(gpcap_pilots_delete)},
 	};
  
+	static const char *ui_description =
+	    "<ui>"
+	    "<popup name='pilotsPopupMenu'>"
+	    " <menuitem action='Edit'/>"
+	    " <menuitem action='Delete'/>"
+	    "</popup>"
+	    "</ui>";
+
+	GtkActionGroup *action_group = gtk_action_group_new ("MenuActions");
+	gtk_action_group_add_actions (action_group, entries, G_N_ELEMENTS (entries), gpcap);
+ 
 	priv = gpcap->priv;
 
 	if (priv->pilots_popup == NULL) {
-		priv->pilots_popup = gtk_menu_new ();
-		gnome_app_fill_menu (GTK_MENU_SHELL (priv->pilots_popup), popup, NULL, TRUE, 0);
+		GtkUIManager *ui_manager = gtk_ui_manager_new ();
+		gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
+
+		GError *error = NULL;
+		if (!gtk_ui_manager_add_ui_from_string (ui_manager, ui_description, -1, &error))
+		{
+			g_message ("building menus failed: %s", error->message);
+			g_error_free (error);
+			exit (EXIT_FAILURE);
+		}
+
+		priv->pilots_popup = gtk_ui_manager_get_widget (ui_manager, "/pilotsPopupMenu");
 	}
 
 	return show_popup_menu (treeview, event, GTK_MENU (priv->pilots_popup));
@@ -961,24 +986,42 @@ gpcap_devices_popup (GtkTreeView *treeview, GdkEventButton *event, gpointer user
 	GnomePilotCapplet *gpcap = GNOME_PILOT_CAPPLET (user_data);
 	GnomePilotCappletPrivate *priv;
 
-	GnomeUIInfo popup [] = {
-		GNOMEUIINFO_ITEM_DATA (N_("_Edit this device..."),
-				       N_("Edit the currently selected device"),
-				       gpcap_devices_edit, gpcap, NULL),
-		GNOMEUIINFO_ITEM_DATA (N_("_Delete this device"),
-				       N_("Delete the currently selected device"),
-				       gpcap_devices_delete, gpcap, NULL),
-		GNOMEUIINFO_END
+	GtkActionEntry entries[] = {
+		{ "Edit", NULL, N_("_Edit this device..."),  NULL,
+		  N_("Edit the currently selected device"), G_CALLBACK(gpcap_devices_edit)},
+		{ "Delete", NULL, N_("_Delete this device"), NULL,
+		  N_("Delete the currently selected device"), G_CALLBACK(gpcap_devices_delete)},
 	};
  
+	static const char *ui_description =
+	    "<ui>"
+	    "<popup name='devicesPopupMenu'>"
+	    " <menuitem action='Edit'/>"
+	    " <menuitem action='Delete'/>"
+	    "</popup>"
+	    "</ui>";
+
+	GtkActionGroup *action_group = gtk_action_group_new ("MenuActions");
+	gtk_action_group_add_actions (action_group, entries, G_N_ELEMENTS (entries), gpcap);
+ 
 	priv = gpcap->priv;
 
 	if (priv->devices_popup == NULL) {
-		priv->pilots_popup = gtk_menu_new ();
-		gnome_app_fill_menu (GTK_MENU_SHELL (priv->pilots_popup), popup, NULL, TRUE, 0);
+		GtkUIManager *ui_manager = gtk_ui_manager_new ();
+		gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
+
+		GError *error = NULL;
+		if (!gtk_ui_manager_add_ui_from_string (ui_manager, ui_description, -1, &error))
+		{
+			g_message ("building menus failed: %s", error->message);
+			g_error_free (error);
+			exit (EXIT_FAILURE);
+		}
+
+		priv->devices_popup = gtk_ui_manager_get_widget (ui_manager, "/devicesPopupMenu");
 	}
 
-	return show_popup_menu (treeview, event, GTK_MENU (priv->pilots_popup));
+	return show_popup_menu (treeview, event, GTK_MENU (priv->devices_popup));
 }
 
 static ConduitState *
@@ -1042,10 +1085,13 @@ gpcap_conduits_choose_pilot (GtkWidget *widget, gpointer user_data)
 	GnomePilotCapplet *gpcap = GNOME_PILOT_CAPPLET (user_data);
 	GnomePilotCappletPrivate *priv;
 	GPilotPilot *pilot;
+	guint index;
 	
 	priv = gpcap->priv;
+	
+	index = gtk_combo_box_get_active(GTK_COMBO_BOX(priv->pilots_combo));
 
-	pilot = gtk_object_get_data (GTK_OBJECT (widget), "pilot");
+	pilot = g_list_nth_data(priv->state->pilots, index);
 
 	set_conduit_pilot (gpcap, pilot);
 }
@@ -1166,33 +1212,48 @@ gpcap_conduits_popup (GtkTreeView *treeview, GdkEventButton *event, gpointer use
 	ConduitState *state;
 	GtkTreePath *path;
 	gboolean test = FALSE, enabled = FALSE;
-	
-	GnomeUIInfo popup [] = {
-		GNOMEUIINFO_ITEM_DATA (N_("_Enable this conduit"),
-				       N_("Disable the currently selected conduit"),
-				       gpcap_conduits_enable, gpcap, NULL),
-		GNOMEUIINFO_ITEM_DATA (N_("_Disable this conduit"),
-				       N_("Enable the currently selected conduit"),
-				       gpcap_conduits_disable, gpcap, NULL),
 
-		GNOMEUIINFO_SEPARATOR,
-
-		GNOMEUIINFO_ITEM_DATA (N_("_Settings..."),
-				       N_("Modify the currently selected conduit's settings"),
-				       gpcap_conduits_settings, gpcap, NULL),
-		
-		GNOMEUIINFO_END
+	GtkActionEntry entries[] = {
+		{ "Enable", NULL, N_("_Enable this conduit"), NULL,
+		  N_("Disable the currently selected conduit"), G_CALLBACK(gpcap_conduits_enable)},
+		{ "Disable", NULL, N_("_Disable this conduit"), NULL,
+		  N_("Enable the currently selected conduit"), G_CALLBACK(gpcap_conduits_disable)},
+		{ "Settings", NULL, N_("_Settings..."), NULL,
+		  N_("Modify the currently selected conduit's settings"), G_CALLBACK(gpcap_conduits_settings)},
 	};
+
+	static const char *ui_description =
+	    "<ui>"
+	    "<popup name='conduitPopupMenu'>"
+	    " <menuitem action='Enable'/>"
+	    " <menuitem action='Disable'/>"
+	    " <separator/>"
+	    " <menuitem action='Settings'/>"
+	    "</popup>"
+	    "</ui>";
+
+	GtkActionGroup *action_group = gtk_action_group_new ("MenuActions");
+	gtk_action_group_add_actions (action_group, entries, G_N_ELEMENTS (entries), gpcap);
  
 	priv = gpcap->priv;
 
 	if (priv->conduit_popup == NULL) {
-		priv->conduit_popup = gtk_menu_new ();
-		gnome_app_fill_menu (GTK_MENU_SHELL (priv->conduit_popup), popup, NULL, TRUE, 0);
+		GtkUIManager *ui_manager = gtk_ui_manager_new ();
+		gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
 
-		priv->conduit_popup_enable = popup[0].widget;
-		priv->conduit_popup_disable = popup[1].widget;
-		priv->conduit_popup_settings = popup[3].widget;
+		GError *error = NULL;
+		if (!gtk_ui_manager_add_ui_from_string (ui_manager, ui_description, -1, &error))
+		{
+			g_message ("building menus failed: %s", error->message);
+			g_error_free (error);
+			exit (EXIT_FAILURE);
+		}
+
+		priv->conduit_popup = gtk_ui_manager_get_widget (ui_manager, "/conduitPopupMenu");
+
+		priv->conduit_popup_enable = gtk_ui_manager_get_widget (ui_manager, "/conduitPopupMenu/Enable");
+		priv->conduit_popup_disable = gtk_ui_manager_get_widget (ui_manager, "/conduitPopupMenu/Disable");
+		priv->conduit_popup_settings = gtk_ui_manager_get_widget (ui_manager, "/conduitPopupMenu/Settings");
 		
 	}
 	
@@ -1293,7 +1354,7 @@ gpcap_dispose (GObject *object)
 
 		g_hash_table_destroy (priv->conduits);
 
-		g_object_unref (priv->xml);
+		g_object_unref (priv->ui);
 
 		if (priv->pilots_popup)
 			gtk_widget_destroy (priv->pilots_popup);
@@ -1306,7 +1367,7 @@ gpcap_dispose (GObject *object)
 
 		/* destroy pilot dialog, if it was loaded */
 		if (priv->pdialog) {
-			gppd_class = gtk_type_class (gnome_pilot_pdialog_get_type());
+			gppd_class = g_type_class_peek (gnome_pilot_pdialog_get_type());
 			if (GTK_OBJECT_CLASS (gppd_class)->destroy)
 				GTK_OBJECT_CLASS (gppd_class)->destroy (priv->pdialog);
 		}
