@@ -28,7 +28,6 @@
  */
 
 #include <sys/stat.h>
-#include <glade/glade.h>
 #include <pi-util.h>
 #include "pilot.h"
 #include "util.h"
@@ -39,7 +38,7 @@ static GtkObjectClass *parent_class = NULL;
 
 struct _GnomePilotPDialogPrivate 
 {
-	GladeXML *xml;
+	GtkBuilder *ui;
 
 	GnomePilotClient *gpc;
 	gint handle1, handle2;
@@ -48,6 +47,8 @@ struct _GnomePilotPDialogPrivate
 	GPilotPilot *pilot;
 
 	GtkWidget *dialog;
+
+	gchar *errstr;
 	
 	GtkWidget *pilot_username;
 	GtkWidget *pilot_id;
@@ -56,6 +57,11 @@ struct _GnomePilotPDialogPrivate
 
 	GtkWidget *pilot_name;
 	GtkWidget *pilot_basedir;
+#ifdef PILOT_LINK_0_12
+	GtkWidget *pilot_charset;
+#endif
+	GtkWidget *pilot_charset_label;
+	GtkWidget *pilot_charset_combo;
 
 	GtkWidget *sync_dialog;
 };
@@ -86,26 +92,26 @@ static void gppd_system_info_requested (GnomePilotClient *gpc,
 
 static void gppd_destroy (GtkObject *object);
 
-GtkType
+GType
 gnome_pilot_pdialog_get_type (void)
 {
-  static GtkType type = 0;
+  static GType type = 0;
 
   if (type == 0)
     {
-      static const GtkTypeInfo info =
+      static const GTypeInfo info =
       {
-        "GnomePilotPDialog",
-        sizeof (GnomePilotPDialog),
         sizeof (GnomePilotPDialogClass),
-        (GtkClassInitFunc) class_init,
-        (GtkObjectInitFunc) init,
-        /* reserved_1 */ NULL,
-        /* reserved_2 */ NULL,
-        (GtkClassInitFunc) NULL,
+        NULL,
+        NULL,
+        (GClassInitFunc) class_init,
+        NULL,
+        NULL,
+        sizeof (GnomePilotPDialog),
+	0,
+        (GInstanceInitFunc) init,
       };
-
-      type = gtk_type_unique (gtk_object_get_type (), &info);
+      type = g_type_register_static (gtk_object_get_type (), "GnomePilotPDialog", &info, 0);
     }
 
   return type;
@@ -118,7 +124,7 @@ class_init (GnomePilotPDialogClass *klass)
 
 	object_class = GTK_OBJECT_CLASS (klass);
 
-	parent_class = gtk_type_class (gtk_object_get_type ());
+	parent_class = g_type_class_peek (gtk_object_get_type ());
 
 	object_class->destroy = gppd_destroy;
 }
@@ -127,20 +133,29 @@ static void
 init (GnomePilotPDialog *gppd)
 {
 	GnomePilotPDialogPrivate *priv;
-	
+	guint error;
+	gchar *objects[] = {"PilotSettings",
+	                    "timeout_adjustment",
+	                    "pilot_charset_store",
+			    NULL};
+
 	priv = g_new0 (GnomePilotPDialogPrivate, 1);
 
 	gppd->priv = priv;
 
 	/* Gui stuff */
-	priv->xml = glade_xml_new (GLADEDATADIR "/gpilotd-capplet.glade", "PilotSettings", NULL);
-	if (!priv->xml) {
-		g_message ("gnome-pilot-pdialog init(): Could not load the Glade XML file!");
-		goto error;
+	priv->ui = gtk_builder_new ();
+	error = gtk_builder_add_objects_from_file (priv->ui, "gpilotd-capplet.ui", objects, NULL);
+	if (error == 0) {
+		error = gtk_builder_add_objects_from_file (priv->ui, UIDATADIR "/gpilotd-capplet.ui", objects, NULL);
+		if (error == 0) {
+			g_message ("gnome-pilot-pdialog init(): Could not load the GtkBuilder UI file!");
+			goto error;
+		}
 	}
 
 	if (!get_widgets (gppd)) {
-		g_message ("gnome-pilot-pdialog init(): Could not find all widgets in the XML file!");
+		g_message ("gnome-pilot-pdialog init(): Could not find all widgets in the UI file!");
 		goto error;
 	}
 
@@ -156,7 +171,7 @@ gnome_pilot_pdialog_new (GnomePilotClient *gpc, PilotState *state, GPilotPilot *
 	GnomePilotPDialog *gppd;
 	GtkObject *object;
 	
-	object = gtk_type_new (GNOME_PILOT_TYPE_PDIALOG);
+	object = GTK_OBJECT(g_type_create_instance (GNOME_PILOT_TYPE_PDIALOG));
 	
 	gppd = GNOME_PILOT_PDIALOG (object);
 	gppd->priv->gpc = gpc;
@@ -177,6 +192,16 @@ gnome_pilot_pdialog_new (GnomePilotClient *gpc, PilotState *state, GPilotPilot *
 	return object;
 }
 
+void
+gnome_pilot_pdialog_set_pilot (GtkObject *obj, GPilotPilot *pilot)
+{
+	GnomePilotPDialog *gppd = GNOME_PILOT_PDIALOG (obj);
+	
+	gppd->priv->pilot = pilot;
+	fill_widgets (gppd);
+}
+
+
 static gboolean
 get_widgets (GnomePilotPDialog *gppd)
 {
@@ -184,7 +209,7 @@ get_widgets (GnomePilotPDialog *gppd)
 
 	priv = gppd->priv;
 
-#define GW(name) glade_xml_get_widget (priv->xml, name)
+#define GW(name) GTK_WIDGET (gtk_builder_get_object (priv->ui, name))
 
 	priv->dialog = GW ("PilotSettings");
 
@@ -195,6 +220,28 @@ get_widgets (GnomePilotPDialog *gppd)
 	
 	priv->pilot_name = GW ("pilot_name_entry");
 	priv->pilot_basedir = GW ("pilot_basedir_entry");
+	priv->pilot_charset_label = GW ("pilot_charset_label");
+	priv->pilot_charset_combo = GW ("pilot_charset_combo");
+#ifdef PILOT_LINK_0_12
+	priv->pilot_charset = gtk_bin_get_child (
+	    GTK_BIN(priv->pilot_charset_combo));
+
+	/* bug in gtkbuilder?  couldn't get the list store to work right with glade,
+	 * so I do it here.
+	 */
+	GtkTreeModel *model = GTK_TREE_MODEL(gtk_builder_get_object (priv->ui,
+		"pilot_charset_store"));
+	gtk_combo_box_set_model (GTK_COMBO_BOX (priv->pilot_charset_combo), model);
+	gtk_combo_box_entry_set_text_column(
+	    GTK_COMBO_BOX_ENTRY (priv->pilot_charset_combo), 0);
+	gtk_cell_layout_clear(GTK_CELL_LAYOUT(priv->pilot_charset_combo));
+	GtkCellRenderer *renderer = gtk_cell_renderer_text_new();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (priv->pilot_charset_combo),
+	    renderer, TRUE);
+	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (priv->pilot_charset_combo),
+	    renderer, "text", 0);
+
+#endif
 	
 #undef GW
 	return (priv->dialog
@@ -203,7 +250,12 @@ get_widgets (GnomePilotPDialog *gppd)
 		&& priv->pilot_get
 		&& priv->pilot_send
 		&& priv->pilot_name
-		&& priv->pilot_basedir);
+		&& priv->pilot_basedir
+#ifdef PILOT_LINK_0_12
+		&& priv->pilot_charset
+#endif
+		&& priv->pilot_charset_label
+		&& priv->pilot_charset_combo);
 }
 
 static void
@@ -213,10 +265,13 @@ map_widgets (GnomePilotPDialog *gppd)
 	
 	priv = gppd->priv;
 
-	gtk_object_set_data (GTK_OBJECT (gppd), "username", priv->pilot_username);
-	gtk_object_set_data (GTK_OBJECT (gppd), "pilotid", priv->pilot_id);
-	gtk_object_set_data (GTK_OBJECT (gppd), "pilotname", priv->pilot_name);
-	gtk_object_set_data (GTK_OBJECT (gppd), "basedir", priv->pilot_basedir);
+	g_object_set_data (G_OBJECT (gppd), "username", priv->pilot_username);
+	g_object_set_data (G_OBJECT (gppd), "pilotid", priv->pilot_id);
+	g_object_set_data (G_OBJECT (gppd), "pilotname", priv->pilot_name);
+	g_object_set_data (G_OBJECT (gppd), "basedir", priv->pilot_basedir);
+#ifdef PILOT_LINK_0_12
+	g_object_set_data (G_OBJECT (gppd), "charset", priv->pilot_charset);
+#endif
 }
 
 static void 
@@ -227,17 +282,17 @@ init_widgets (GnomePilotPDialog *gppd)
 	priv = gppd->priv;
 
 	/* Button signals */
-	gtk_signal_connect (GTK_OBJECT (priv->pilot_get), "clicked",
-			    GTK_SIGNAL_FUNC (gppd_pilot_get), gppd);
+	g_signal_connect (GTK_OBJECT (priv->pilot_get), "clicked",
+			    G_CALLBACK (gppd_pilot_get), gppd);
 
-	gtk_signal_connect (GTK_OBJECT (priv->pilot_send), "clicked",
-			    GTK_SIGNAL_FUNC (gppd_pilot_send), gppd);
+	g_signal_connect (GTK_OBJECT (priv->pilot_send), "clicked",
+			    G_CALLBACK (gppd_pilot_send), gppd);
 	
 	/* Other widget signals */
-	gtk_signal_connect (GTK_OBJECT (priv->pilot_username),"insert-text",
-			    GTK_SIGNAL_FUNC (insert_username_callback), NULL);
-	gtk_signal_connect (GTK_OBJECT (priv->pilot_id),"insert-text",
-			    GTK_SIGNAL_FUNC (insert_numeric_callback), NULL);
+	g_signal_connect (GTK_OBJECT (priv->pilot_username),"insert-text",
+			    G_CALLBACK (insert_username_callback), NULL);
+	g_signal_connect (GTK_OBJECT (priv->pilot_id),"insert-text",
+			    G_CALLBACK (insert_numeric_callback), NULL);
 }
 
 static void
@@ -256,6 +311,12 @@ fill_widgets (GnomePilotPDialog *gppd)
 
 		gtk_entry_set_text (GTK_ENTRY (priv->pilot_name), priv->pilot->name);
 		gtk_entry_set_text (GTK_ENTRY (priv->pilot_basedir), priv->pilot->sync_options.basedir);
+#ifndef PILOT_LINK_0_12
+		gtk_widget_set_sensitive (priv->pilot_charset_label, FALSE);
+		gtk_widget_set_sensitive (priv->pilot_charset_combo, FALSE);
+#else
+		gtk_entry_set_text (GTK_ENTRY (priv->pilot_charset), priv->pilot->pilot_charset);
+#endif
 	}
 }
 
@@ -272,10 +333,20 @@ gnome_pilot_pdialog_run_and_close (GnomePilotPDialog *gppd, GtkWindow *parent)
 		btn = gtk_dialog_run (GTK_DIALOG (priv->dialog));
 	
 		if (btn == GTK_RESPONSE_OK) {
-			if(check_base_directory(gtk_entry_get_text(
-				GTK_ENTRY(priv->pilot_basedir)))) {
-				read_pilot_config (GTK_OBJECT (gppd), priv->pilot);
+			if(
+#ifdef PILOT_LINK_0_12
+			    check_pilot_charset(gtk_entry_get_text(
+				    GTK_ENTRY(priv->pilot_charset)), &priv->errstr) &&
+#endif
+			    check_base_directory(gtk_entry_get_text(
+				    GTK_ENTRY(priv->pilot_basedir)), &priv->errstr)) {
+				read_pilot_config (GTK_OBJECT (gppd),
+				    priv->pilot);
 				break;
+			} else {
+				error_dialog (GTK_WINDOW (priv->dialog), priv->errstr);
+				g_free(priv->errstr);
+				priv->errstr = NULL;
 			}
 		} else {
 			break;
@@ -327,7 +398,11 @@ gppd_userinfo_requested (GnomePilotClient *gpc,
 
 	if (priv->pilot->pilot_username) 
 		g_free (priv->pilot->pilot_username);
+#ifndef PILOT_LINK_0_12
 	if (!user->username || (convert_FromPilotChar ("UTF-8", user->username, strlen (user->username), &priv->pilot->pilot_username ) == -1)) {
+#else
+	if (!user->username || (convert_FromPilotChar_WithCharset ("UTF-8", user->username, strlen (user->username), &priv->pilot->pilot_username, NULL ) == -1)) {
+#endif
   		priv->pilot->pilot_username = g_strdup (user->username);
 	}
 
@@ -440,7 +515,11 @@ gppd_pilot_send (GtkWidget *widget, gpointer user_data)
 		read_pilot_config (GTK_OBJECT (gppd), pilot);
 
 		user.userID = pilot->pilot_id;
+#ifndef PILOT_LINK_0_12
 		if (! pilot->pilot_username || (convert_ToPilotChar ("UTF-8", pilot->pilot_username,strlen(pilot->pilot_username),&user.username) == -1)) {
+#else
+		if (! pilot->pilot_username || (convert_ToPilotChar_WithCharset ("UTF-8", pilot->pilot_username, strlen(pilot->pilot_username), &user.username, NULL) == -1)) {
+#endif
 			user.username = g_strdup (pilot->pilot_username);
 		}
 		if (gnome_pilot_client_set_user_info (priv->gpc, 
@@ -472,9 +551,10 @@ gppd_destroy (GtkObject *object)
 	priv = gppd->priv;
 
 	gtk_widget_destroy (priv->dialog);
-	gtk_object_unref (GTK_OBJECT (priv->xml));
+	g_object_unref (G_OBJECT (priv->ui));
 
-	gtk_signal_disconnect_by_data (GTK_OBJECT (priv->gpc), object);
+	g_signal_handlers_disconnect_matched (priv->gpc,
+	    G_SIGNAL_MATCH_DATA, 0, 0, NULL, NULL, object);
 	
 	if (GTK_OBJECT_CLASS (parent_class)->destroy)
 		(* GTK_OBJECT_CLASS (parent_class)->destroy) (object);
