@@ -25,10 +25,12 @@
 /* handles pilot issues */
 
 #include <config.h>
-#include <gnome.h>
+#include <glib.h>
 #include <pi-util.h>
 
+#include <gpilotd/gnome-pilot-config.h>
 #include "pilot.h"
+#include "util.h"
 
 /* create new pilotstate structure, initialize to sane state */
 PilotState
@@ -62,6 +64,9 @@ copy_pilot (GPilotPilot *pilot, PilotState *dest)
     pilot2->creation = pilot->creation;
     pilot2->romversion = pilot->romversion;
     pilot2->sync_options.basedir = g_strdup (pilot->sync_options.basedir);
+#ifdef PILOT_LINK_0_12
+    pilot2->pilot_charset = g_strdup (pilot->pilot_charset);
+#endif
     dest->pilots = g_list_append (dest->pilots, pilot2);
 }
 
@@ -96,46 +101,74 @@ freePilotState (PilotState *state)
 static gint
 loadHostID (PilotState *p)
 {
-    guint32  id;
-    gboolean notfound;
+    guint     id;
+    gboolean  ret;
+    GError   *error = NULL;
+    GKeyFile *kfile = NULL;
 
-    gnome_config_push_prefix ("/gnome-pilot.d/gpilotd/General/");
-    id = gnome_config_get_int_with_default ("sync_PC_Id=0", &notfound);
-    p->progress_stepping = gnome_config_get_int_with_default ("progress_stepping=5", NULL);
-    gnome_config_pop_prefix ();
-  
-    if (notfound) {
-	p->syncPCid = random ();
-	return -1;
-    } else {
-	p->syncPCid = id;
-	return 0;
+    kfile = get_gpilotd_kfile ();
+    if (kfile == NULL) {
+        p->syncPCid = random ();
+        return -1;
     }
-}    
+
+    ret = 0;
+    id = g_key_file_get_integer (kfile, "General", "sync_PC_Id", &error);
+    if (error) {
+        g_warning (_("Unable load key gpilotd/General/sync_PC_Id: %s"), error->message);
+        g_error_free (error);
+        error = NULL;
+        ret = -1;
+        p->syncPCid = random ();
+    } else {
+	if (id ==0)
+		p->syncPCid = random ();
+	else
+		p->syncPCid = id;
+    }
+
+    p->progress_stepping = g_key_file_get_integer (kfile, "General", "progress_stepping", &error);
+    if (error) {
+        g_warning (_("Unable load key gpilotd/General/progress_stepping: %s"), error->message);
+        g_error_free (error);
+        error = NULL;
+	p->progress_stepping = 5;
+    }
+  
+    g_key_file_free (kfile);
+    return ret;
+}
 
 static gint
 loadDeviceCfg (PilotState *p)
 {
   GPilotDevice *device;
-  gchar *prefix;
-  gchar buf[25];
+  gchar        *iDevice;
+  GKeyFile     *kfile = NULL;
+  GError       *error = NULL;
   int i, num;
 
-  gnome_config_push_prefix ("/gnome-pilot.d/gpilotd/General/");
-  num = gnome_config_get_int ("num_devices=0");
-  gnome_config_pop_prefix ();
+  kfile = get_gpilotd_kfile ();
+  num = g_key_file_get_integer (kfile, "General", "num_devices", NULL);
 
   if (num == 0) {
-	  g_message ("No pilot cradle information located");
-	  p->devices = NULL;
-	  return -1;
+      g_message ("No pilot cradle information located");
+      p->devices = NULL;
+      g_key_file_free (kfile);
+      return -1;
   } else {
 	  for (i=0;i<num;i++){
 		  device = g_new0(GPilotDevice, 1);
-		  prefix = g_strdup_printf ("/gnome-pilot.d/gpilotd/Device%d/", i);
+                  iDevice = g_strdup_printf ("Device%d", i);
 		  
-		  gnome_config_push_prefix (prefix);
-		  device->type = gnome_config_get_int ("type=0");
+		  device->type = g_key_file_get_integer (kfile, iDevice, "type", &error);
+		  if (error) {
+			  g_warning (_("Unable load key gpilotd/%s/type: %s"), iDevice, error->message);
+			  g_error_free (error);
+			  error = NULL;
+			  device->type = 0;
+		  };
+
 		  if (device->type == PILOT_DEVICE_SERIAL) {
 			  g_message ("Cradle Type -> Serial");
 		  } else if (device->type == PILOT_DEVICE_USB_VISOR) {
@@ -144,30 +177,53 @@ loadDeviceCfg (PilotState *p)
 			  g_message ("Cradle Type -> IrDA");
 		  } else if (device->type == PILOT_DEVICE_NETWORK) {
 			  g_message ("Cradle Type -> Network");
+		  } else if (device->type == PILOT_DEVICE_BLUETOOTH) {
+			  g_message ("Cradle Type -> Bluetooth");
 		  } else {
-		      g_warning ("Unknown Cradle Type");
+			  g_warning ("Unknown Cradle Type");
 		  }
 
-		  sprintf (buf,"name=Cradle%d", i);
-		  device->name = gnome_config_get_string (buf);
+		  device->name = g_key_file_get_string (kfile, iDevice, "name", &error);
+		  if (error) {
+			  g_warning (_("Unable load key gpilotd/%s/name: iDevice, %s"), iDevice, error->message);
+			  g_error_free (error);
+			  error = NULL;
+			  g_free (device->name);
+			  device->name = g_strdup_printf ("Cradle%d", i);
+		  };
 		  g_message ("cradle device name -> %s", device->name);
 
 		  if (device->type == PILOT_DEVICE_NETWORK) {
-			  device->ip = gnome_config_get_string ("ip");
+			  device->ip = g_key_file_get_string (kfile, iDevice, "ip", NULL);
 			  g_message ("cradle network ip -> %s", device->ip);
+		  } else if (device->type == PILOT_DEVICE_BLUETOOTH) {
+			  /* no more parameters */
 		  } else {
-			  device->port = gnome_config_get_string ("device");
+			  device->port = g_key_file_get_string (kfile, iDevice, "device", NULL);
 			  g_message ("cradle device name -> %s", device->port);
-			  device->speed = gnome_config_get_int ("speed=9600");
+			  device->speed = g_key_file_get_integer (kfile, iDevice, "speed", &error);
+			  if (error) {
+				  g_warning (_("Unable load key gpilotd/%s/speed: %s"), iDevice, error->message);
+				  g_error_free (error);
+				  error = NULL;
+				  device->speed = 9600;
+			  };
 			  g_message ("Pilot Speed  -> %d", device->speed);  		  
 		  }
-		  device->timeout = gnome_config_get_int ("timeout=2");
+		  device->timeout = g_key_file_get_integer (kfile, iDevice, "timeout", &error);
+		  if (error) {
+			  g_warning (_("Unable load key gpilotd/%s/timeout: %s"), iDevice, error->message);
+			  g_error_free (error);
+			  error = NULL;
+			  device->timeout = 2;
+		  };
 		  g_message ("Timeout -> %d", device->timeout);
-		  gnome_config_pop_prefix ();
-		  g_free (prefix);
+		  g_free (iDevice);
 		  p->devices = g_list_append (p->devices, device);
 	  }
   }
+
+  g_key_file_free (kfile);
   return 0;
 }
 
@@ -176,57 +232,83 @@ static gint
 loadPilotPilot (PilotState *p)
 {
   GPilotPilot *pilot;
-  gboolean notfound;
-  gchar *prefix;
+  gchar *iPilot;
   char *local_name;
   int i, num;
+  GKeyFile *kfile;
+  GError *error = NULL;
 
-  gnome_config_push_prefix ("/gnome-pilot.d/gpilotd/General/");
-  num = gnome_config_get_int ("num_pilots=0");
-  gnome_config_pop_prefix ();
+  kfile = get_gpilotd_kfile ();
+
+  num = g_key_file_get_integer (kfile, "General", "num_pilots", NULL);
 
   if (num == 0) {
       g_message ("No pilot userid/username information located");
       p->pilots = NULL;
+      g_key_file_free (kfile);
       return -1;
   } else {
 	  for (i=0;i<num;i++){
 		  pilot = g_new0(GPilotPilot, 1);
-		  prefix = g_strdup_printf ("/gnome-pilot.d/gpilotd/Pilot%d/", i);
-		  gnome_config_push_prefix (prefix);
-		  pilot->name = gnome_config_get_string ("name=MyPilot");
+		  iPilot = g_strdup_printf ("Pilot%d", i);
+
+                  pilot->name = g_key_file_get_string (kfile, iPilot, "name", &error);
+		  if (error) {
+			  g_warning (_("Unable load key gpilotd/%s/name: %s"), iPilot, error->message);
+			  g_error_free (error);
+			  error = NULL;
+			  g_free (pilot->name);
+			  pilot->name = g_strdup ("MyPilot");
+		  };
 		  g_message ("Pilot name -> %s", pilot->name);
-		  pilot->pilot_id = gnome_config_get_int_with_default ("pilotid",&notfound);
-		  if (notfound)
+
+		  pilot->pilot_id = g_key_file_get_integer (kfile, iPilot, "pilotid", &error);
+		  if (error) {
+			  g_warning (_("Unable load key gpilotd/%s/pilotid: %s"), iPilot, error->message);
+			  g_error_free (error);
+			  error = NULL;
 			  pilot->pilot_id = getuid ();
+                  }
 		  g_message ("Pilot id   -> %d", pilot->pilot_id);
-		  local_name = gnome_config_get_string ("pilotusername");
+		  local_name = g_key_file_get_string (kfile, iPilot, "pilotusername", NULL);
+#ifdef PILOT_LINK_0_12
+		  if (!local_name || (convert_FromPilotChar_WithCharset ("UTF-8", local_name, strlen(local_name), &pilot->pilot_username, NULL) == -1)) {
+#else
 		  if (!local_name || (convert_FromPilotChar ("UTF-8", local_name, strlen(local_name), &pilot->pilot_username) == -1)) {
+#endif
   		  	pilot->pilot_username = g_strdup (local_name);
 		  }
 		  g_free (local_name);
 		  g_message ("Pilot username -> %s", pilot->pilot_username);
 	  
-		  pilot->creation = gnome_config_get_int ("creation");
-		  pilot->romversion = gnome_config_get_int ("romversion");
+		  pilot->creation = g_key_file_get_integer (kfile, iPilot, "creation", NULL);
+		  pilot->romversion = g_key_file_get_integer (kfile, iPilot, "romversion", NULL);
 		  
 		  g_message ("Pilot creation/rom = %lu/%lu", pilot->creation, pilot->romversion);
 
-		  pilot->sync_options.basedir = gnome_config_get_string ("basedir");
+		  pilot->sync_options.basedir = g_key_file_get_string (kfile, iPilot, "basedir", NULL);
 		  if (pilot->sync_options.basedir==NULL) {
 			  pilot->sync_options.basedir = g_strdup_printf ("%s/%s", g_get_home_dir (), pilot->name);
 		  }
 	  
-		  /* set these to something sane since we arent using them */
-		  pilot->trusted_users = NULL;
+#ifdef PILOT_LINK_0_12
+		  pilot->pilot_charset = g_key_file_get_string (kfile, iPilot, "charset", NULL);
+		  if (pilot->pilot_charset == NULL)
+			  pilot->pilot_charset =
+			      g_strdup(get_default_pilot_charset());
+#else
+		  pilot->pilot_charset = NULL;
+#endif
+
 		  pilot->number = i;
 	  
-		  g_free (prefix);
-		  gnome_config_pop_prefix ();
+		  g_free (iPilot);
 		  
 		  p->pilots = g_list_append (p->pilots, pilot);
 	  }
   }
+
+  g_key_file_free (kfile);
   return 0;
 }
 
@@ -261,41 +343,43 @@ savePilotState (PilotState *state)
 {
   int i;
   GList *tmp;
-  gchar *prefix;
+  gchar *iDevice;
+  gchar *iPilot;
   char *local_name;
+  GKeyFile *kfile;
 
-  gnome_config_clean_section ("/gnome-pilot.d/gpilotd/General/");
+  kfile = get_gpilotd_kfile ();
 
-  gnome_config_set_int ("/gnome-pilot.d/gpilotd/General/sync_PC_Id", state->syncPCid);
-  gnome_config_set_int ("/gnome-pilot.d/gpilotd/General/progress_stepping", state->progress_stepping);
+  g_key_file_remove_group (kfile, "General", NULL);
+
+  g_key_file_set_integer (kfile, "General", "sync_PC_Id", state->syncPCid);
+  g_key_file_set_integer (kfile, "General", "progress_stepping", state->progress_stepping);
 
   tmp = state->devices;
   i=0;
   while (tmp!=NULL)
   {
 	  GPilotDevice *device=(GPilotDevice*)tmp->data;
-	  prefix = g_strdup_printf ("/gnome-pilot.d/gpilotd/Device%d/", i);
+	  iDevice = g_strdup_printf ("Device%d", i);
 
-	  gnome_config_clean_section (prefix);
-	  gnome_config_push_prefix (prefix);
-	  gnome_config_set_int ("type", device->type);
-	  gnome_config_set_string ("name", device->name);
+	  g_key_file_remove_group (kfile, iDevice, NULL);
+	  g_key_file_set_integer (kfile, iDevice, "type", device->type);
+	  g_key_file_set_string (kfile, iDevice, "name", device->name);
 	  if (device->type == PILOT_DEVICE_NETWORK) {
-		  gnome_config_set_string ("ip", device->ip);
+		  g_key_file_set_string (kfile, iDevice, "ip", device->ip);
+	  } else if (device->type == PILOT_DEVICE_BLUETOOTH) {
+		  /* no further info stored */
 	  } else {
-		  gnome_config_set_string ("device", device->port);
-		  gnome_config_set_int ("speed", device->speed);
+		  g_key_file_set_string (kfile, iDevice, "device", device->port);
+		  g_key_file_set_integer (kfile, iDevice, "speed", device->speed);
 	  }
-	  gnome_config_set_int ("timeout", device->timeout);
-	  gnome_config_pop_prefix ();
-	  g_free (prefix);
+	  g_key_file_set_integer (kfile, iDevice, "timeout", device->timeout);
+	  g_free (iDevice);
 	  tmp = tmp->next;
 	  i++;
   }  
   if (i>0) {
-      gnome_config_push_prefix ("/gnome-pilot.d/gpilotd/General/");
-      gnome_config_set_int ("num_devices", i);
-      gnome_config_pop_prefix ();
+      g_key_file_set_integer (kfile, "General", "num_devices", i);
   }
 
   tmp = state->pilots;
@@ -303,32 +387,37 @@ savePilotState (PilotState *state)
   while (tmp!=NULL)
   {
 	  GPilotPilot *pilot=(GPilotPilot*)tmp->data;
-	  prefix = g_strdup_printf ("/gnome-pilot.d/gpilotd/Pilot%d/", i);
-	  gnome_config_clean_section (prefix);
+	  iPilot = g_strdup_printf ("Pilot%d", i);
 
-	  gnome_config_push_prefix (prefix);
-	  gnome_config_set_string ("name", pilot->name);
-	  gnome_config_set_int ("pilotid", pilot->pilot_id);
-	  gnome_config_set_int ("creation", pilot->creation);
-	  gnome_config_set_int ("romversion", pilot->romversion);
-	  if (!pilot->pilot_username|| (convert_ToPilotChar ("UTF-8", pilot->pilot_username, strlen (pilot->pilot_username),&local_name) == -1)) {
+	  g_key_file_remove_group (kfile, iPilot, NULL);
+	  g_key_file_set_string (kfile, iPilot, "name", pilot->name);
+	  g_key_file_set_integer (kfile, iPilot, "pilotid", pilot->pilot_id);
+	  g_key_file_set_integer (kfile, iPilot, "creation", pilot->creation);
+	  g_key_file_set_integer (kfile, iPilot, "romversion", pilot->romversion);
+#ifdef PILOT_LINK_0_12
+	  if (!pilot->pilot_username|| (convert_ToPilotChar_WithCharset ("UTF-8", pilot->pilot_username, strlen (pilot->pilot_username), &local_name, NULL) == -1)) {
+#else
+	  if (!pilot->pilot_username|| (convert_ToPilotChar ("UTF-8", pilot->pilot_username, strlen (pilot->pilot_username), &local_name) == -1)) {
+#endif
 		  local_name = g_strdup (pilot->pilot_username);
 	  }
-	  gnome_config_set_string ("pilotusername", local_name);
+	  g_key_file_set_string (kfile, iPilot, "pilotusername", local_name);
 	  g_free (local_name);
-	  gnome_config_set_string ("basedir", pilot->sync_options.basedir);
-	  gnome_config_pop_prefix ();
-	  g_free (prefix);
+	  g_key_file_set_string (kfile, iPilot, "basedir", pilot->sync_options.basedir);
+#ifdef PILOT_LINK_0_12
+	  g_key_file_set_string (kfile, iPilot, "charset", pilot->pilot_charset);
+#endif
+	  g_free (iPilot);
 	  tmp = tmp->next;
 	  i++;
   }
   if (i>0) {
-      gnome_config_push_prefix ("/gnome-pilot.d/gpilotd/General/");
-      gnome_config_set_int ("num_pilots", i);
-      gnome_config_pop_prefix ();
+      g_key_file_set_integer (kfile, "General", "num_pilots", i);
   }
 
-  gnome_config_sync ();
+  save_gpilotd_kfile (kfile);
+  g_key_file_free (kfile);
+
   return 0;
 }
 
@@ -338,7 +427,7 @@ load_conduit_list (GPilotPilot *pilot)
 {
 	GList *conduits = NULL, *conduit_states = NULL;
 	gchar *buf;
-		
+
 	gnome_pilot_conduit_management_get_conduits (&conduits, GNOME_PILOT_CONDUIT_MGMT_NAME);
 	conduits = g_list_sort (conduits, (GCompareFunc) strcmp);
 	while (conduits != NULL) {
@@ -353,7 +442,7 @@ load_conduit_list (GPilotPilot *pilot)
 		conduit_state->description = g_strdup ((gchar*) gnome_pilot_conduit_management_get_attribute (conduit_state->management, "description", NULL));
 		conduit_state->icon = g_strdup ((gchar*)gnome_pilot_conduit_management_get_attribute (conduit_state->management, "icon", NULL));
 		if (conduit_state->icon == NULL || g_file_test (conduit_state->icon, G_FILE_TEST_IS_REGULAR)==FALSE) {
-			conduit_state->icon = gnome_unconditional_pixmap_file ("gnome-palm-conduit.png");
+			conduit_state->icon = g_strdup_printf ("%s/%s", GNOMEPIXMAPSDIR, "gnome-palm-conduit.png");
 		}
 		
 		buf = (gchar*) gnome_pilot_conduit_management_get_attribute (conduit_state->management, "settings", NULL);
