@@ -26,110 +26,181 @@
 #include <sys/stat.h>
 #include <errno.h>
 #include <ctype.h>
-#include <glade/glade.h>
 #include <errno.h>
 #include "util.h"
+#include <iconv.h>
+#include <gtk/gtk.h>
 
 static const guint speedList[] = {9600, 19200, 38400, 57600, 115200, 0};
 #define  DEFAULT_SPEED_INDEX  3  /* Default to 57600 */
 
 void
-fill_speed_menu (GtkOptionMenu *option_menu, guint default_speed)
+fill_speed_combo (GtkComboBox *option_combo)
 {
-	gint i = 0, n = DEFAULT_SPEED_INDEX;
-	GtkWidget *menu ,*menu_item;
-	gchar buf[20];
+        gint i = 0;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
 
-	g_return_if_fail (option_menu != NULL);
-	g_return_if_fail (GTK_IS_OPTION_MENU (option_menu));
+        gchar *text;
 
-	menu = gtk_menu_new ();
+        g_return_if_fail (option_combo != NULL);
+        g_return_if_fail (GTK_IS_COMBO_BOX (option_combo));
 
-	while (speedList[i] != 0) {
-		g_snprintf (buf,sizeof (buf),"%d",speedList[i]);
-		menu_item = gtk_menu_item_new_with_label (buf);
-		gtk_widget_show (menu_item);
-		gtk_object_set_data (GTK_OBJECT (menu_item), "speed", GINT_TO_POINTER (speedList[i]));
-		gtk_menu_append (GTK_MENU (menu),menu_item);
-		
-		if (speedList[i] == default_speed)
-			n = i;
-		i++;
-	}
-	gtk_option_menu_set_menu (option_menu, menu);	
-	gtk_option_menu_set_history (option_menu, n);
+	model = gtk_combo_box_get_model (option_combo);
+	if (model != NULL)
+		/* tree model not empty -- don't reinitialise */
+		return;
+
+	model = GTK_TREE_MODEL(gtk_list_store_new (1, G_TYPE_STRING));
+	i = 0;
+        while (speedList[i] != 0) {
+		text = g_strdup_printf ("%d", speedList[i]);
+		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, text, -1);
+		g_free(text);
+                i++;
+        }
+	gtk_combo_box_set_model (option_combo, model);
+
+	gtk_cell_layout_clear(GTK_CELL_LAYOUT(option_combo));
+	GtkCellRenderer *renderer = gtk_cell_renderer_text_new();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (option_combo),
+	    renderer, TRUE);
+	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (option_combo),
+	    renderer, "text", 0);
+
+        gtk_combo_box_set_active(option_combo, DEFAULT_SPEED_INDEX);
 }
 
-void 
-fill_conduit_sync_type_menu (GtkOptionMenu *option_menu, ConduitState *state)
+/* return false if an invalid speed was supplied */
+gboolean
+speed_combo_set_speed (GtkComboBox *option_combo, int speed)
 {
-	GtkWidget *menu_item;
-	GtkMenu   *menu;
-	GList *tmp;
-	int index, current=0;
-	
-	menu = GTK_MENU (gtk_menu_new ());
+	gint i;
 
-	menu_item = gtk_menu_item_new_with_label(_("Disabled"));
-	gtk_widget_show(menu_item);
-	gtk_object_set_data (GTK_OBJECT (menu_item), "sync_type", GINT_TO_POINTER (GnomePilotConduitSyncTypeNotSet));
-	gtk_menu_append (menu, menu_item);
+	i = 0;
+	while(speedList[i] != 0) {
+		if (speedList[i] == speed) {
+			gtk_combo_box_set_active(option_combo, i);
+			return TRUE;
+		}
+		i++;
+	}
+	return FALSE;
+}
+
+int
+speed_combo_get_speed (GtkComboBox *option_combo)
+{
+	return speedList[gtk_combo_box_get_active(option_combo)];
+}
+
+
+void 
+fill_conduit_sync_type_combo (GtkComboBox *option_combo, ConduitState *state)
+{
+	int current = 0;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	GList *tmp;
+	int index;
+
+        g_return_if_fail (option_combo != NULL);
+        g_return_if_fail (GTK_IS_COMBO_BOX (option_combo));
+
+	model = gtk_combo_box_get_model (option_combo);
+
+	if (model != NULL) {
+		/* we have to set combo box active row to match current sync state,
+		 * so just as easy to start again.
+		 */
+		gtk_list_store_clear(GTK_LIST_STORE(model));
+	} else {
+		model = GTK_TREE_MODEL(gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT));
+	}
+
+	gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+	gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, _("Disabled"),
+	    1, GnomePilotConduitSyncTypeNotSet, -1);
 
 	tmp = state->valid_synctypes;
 	if (tmp == NULL && state->default_sync_type == GnomePilotConduitSyncTypeCustom ) {
-			menu_item = gtk_menu_item_new_with_label(_("Enabled"));
-			gtk_widget_show(menu_item);
-			gtk_object_set_data (GTK_OBJECT (menu_item), "sync_type", GINT_TO_POINTER (state->default_sync_type));
-			gtk_menu_append (menu, menu_item);
-			if (state->sync_type == state->default_sync_type) 
-				current = 1;
+		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, _("Enabled"),
+		    1, state->default_sync_type, -1);
+		if (state->sync_type == state->default_sync_type) 
+			current = 1;
 	} else {
-		for (index = 0; tmp != NULL; tmp = tmp->next, index++) {
-			gint value = GPOINTER_TO_INT (tmp->data);
-			
-			menu_item = gtk_menu_item_new_with_label (sync_type_to_str (value));
-			gtk_widget_show (menu_item);
-			gtk_object_set_data (GTK_OBJECT (menu_item), "sync_type", GINT_TO_POINTER (value));
-			gtk_menu_append (menu,menu_item);
-			if (value == state->sync_type) 
+		for (index = 0; tmp != NULL; tmp = tmp->next, index++) {		
+			gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+			gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+			    0, sync_type_to_str(GPOINTER_TO_INT (tmp->data)),
+			    1, GPOINTER_TO_INT(tmp->data), -1);
+			if (GPOINTER_TO_INT(tmp->data) == state->sync_type) 
 				current = index + 1;
 		}
 	}
-	
+	gtk_combo_box_set_model (option_combo, model);
 
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), GTK_WIDGET (menu));
-	gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), current);
+	gtk_cell_layout_clear(GTK_CELL_LAYOUT(option_combo));
+	GtkCellRenderer *renderer = gtk_cell_renderer_text_new();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (option_combo),
+	    renderer, TRUE);
+	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (option_combo),
+	    renderer, "text", 0);
+
+        gtk_combo_box_set_active(option_combo, current);
 }
 
 void 
-fill_conduit_first_sync_type_menu (GtkOptionMenu *option_menu, ConduitState *state)
+fill_conduit_first_sync_type_combo (GtkComboBox *option_combo, ConduitState *state)
 {
-	GtkWidget *menu_item;
-	GtkMenu   *menu;
-	GList *tmp;
-	int index, current=0;
-	
-	menu = GTK_MENU (gtk_menu_new ());
+	int current = 0;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	GList *tmp = NULL;
+	int index;
 
-	menu_item = gtk_menu_item_new_with_label(_("None"));
-	gtk_widget_show(menu_item);
-	gtk_object_set_data (GTK_OBJECT (menu_item), "sync_type", GINT_TO_POINTER (GnomePilotConduitSyncTypeNotSet));
-	gtk_menu_append (menu, menu_item);
+        g_return_if_fail (option_combo != NULL);
+        g_return_if_fail (GTK_IS_COMBO_BOX (option_combo));
 
-	tmp = state->valid_synctypes;
-	for (index = 0; tmp != NULL; tmp = tmp->next, index++) {
-		gint value = GPOINTER_TO_INT (tmp->data);
-		
-		menu_item = gtk_menu_item_new_with_label (sync_type_to_str (value));
-		gtk_widget_show (menu_item);
-		gtk_object_set_data (GTK_OBJECT (menu_item), "sync_type", GINT_TO_POINTER (value));
-		gtk_menu_append (menu,menu_item);
-		if (value == state->first_sync_type) 
-			current = index + 1;
+	model = gtk_combo_box_get_model (option_combo);
+	if (model != NULL) {
+		/* we have to set combo box active row to match current sync state,
+		 * so just as easy to start again.
+		 */
+		gtk_list_store_clear(GTK_LIST_STORE(model));
+	} else {
+		model = GTK_TREE_MODEL(gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT));
 	}
 
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), GTK_WIDGET (menu));
-	gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), current);
+	model = GTK_TREE_MODEL(gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT));
+
+	gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+	gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, _("None"),
+	    1, GnomePilotConduitSyncTypeNotSet, -1);
+
+	if (state->default_sync_type != GnomePilotConduitSyncTypeCustom) {
+		tmp = state->valid_synctypes;
+	}
+	for (index = 0; tmp != NULL; tmp = tmp->next, index++) {
+		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
+		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
+		    0, sync_type_to_str(GPOINTER_TO_INT (tmp->data)),
+		    1, GPOINTER_TO_INT(tmp->data), -1);
+		if (GPOINTER_TO_INT(tmp->data) == state->sync_type) 
+			current = index + 1;
+	}
+	gtk_combo_box_set_model (option_combo, model);
+
+	gtk_cell_layout_clear(GTK_CELL_LAYOUT(option_combo));
+	GtkCellRenderer *renderer = gtk_cell_renderer_text_new();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (option_combo),
+	    renderer, TRUE);
+	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (option_combo),
+	    renderer, "text", 0);
+
+        gtk_combo_box_set_active(option_combo, current);
 }
 
 gboolean
@@ -163,7 +234,7 @@ error_dialog (GtkWindow *parent, gchar *mesg, ...)
 	tmp = g_strdup_vprintf (mesg,ap);
 
 	dlg = gtk_message_dialog_new (parent, GTK_DIALOG_DESTROY_WITH_PARENT, 
-				      GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, tmp);
+	    GTK_MESSAGE_ERROR, GTK_BUTTONS_OK, "%s", tmp);
 	gtk_dialog_run (GTK_DIALOG (dlg));
 	gtk_widget_destroy (dlg);
 	
@@ -171,42 +242,62 @@ error_dialog (GtkWindow *parent, gchar *mesg, ...)
 	g_free (tmp);
 }
 
+const char *
+get_default_pilot_charset(void) {
+	const char *pc;
+
+	if ((pc = getenv("PILOT_CHARSET")) == NULL) {
+		pc = GPILOT_DEFAULT_CHARSET;
+	}
+	return pc;
+}
+
 static GPilotDevice *
 real_choose_pilot_dialog (PilotState *state) 
 {
-	GladeXML *xml;
+	GtkBuilder *ui;
 	GtkWidget *dlg;
-	GtkWidget *option_menu, *menu_item, *menu;
+	GtkWidget *device_combo;
 	GList *tmp;
+	GtkListStore *list_store;
+	GtkCellRenderer *renderer;
 	GPilotDevice *dev;
+        guint index;
+	gchar *objects[] = {"ChooseDevice", NULL};
 	
-	xml = glade_xml_new (GLADEDATADIR "/gpilotd-capplet.glade", "ChooseDevice", NULL);
-	dlg = glade_xml_get_widget (xml,"ChooseDevice");
-	option_menu = glade_xml_get_widget (xml, "device_menu");
+	ui = gtk_builder_new ();
+	gtk_builder_add_objects_from_file (ui, UIDATADIR "/gpilotd-capplet.ui", objects, NULL);
+	dlg = GTK_WIDGET (gtk_builder_get_object (ui,"ChooseDevice"));
+	device_combo = GTK_WIDGET (gtk_builder_get_object (ui, "device_combo"));
 
-	gtk_object_set_data (GTK_OBJECT (dlg), "device_menu", option_menu);
-	
-	menu = gtk_menu_new ();
+	g_object_set_data (G_OBJECT (dlg), "device_combo", device_combo);
+
+	list_store = gtk_list_store_new (1, G_TYPE_STRING);
+	gtk_combo_box_set_model (GTK_COMBO_BOX (device_combo), GTK_TREE_MODEL (list_store));
+	renderer = gtk_cell_renderer_text_new();
+	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (device_combo), renderer, TRUE);
+	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT (device_combo), renderer, "text", 0);
 
 	tmp = state->devices;
 	while (tmp != NULL){
+		GtkTreeIter iter;
+
+		gtk_list_store_append (list_store, &iter);
 		dev =(GPilotDevice*)tmp->data;
 		if(dev->type == PILOT_DEVICE_NETWORK) {
-			menu_item = gtk_menu_item_new_with_label ("[network]");
+			gtk_list_store_set (list_store, &iter, 0, "[network]", -1);
+		} else if(dev->type == PILOT_DEVICE_BLUETOOTH) {
+			gtk_list_store_set (list_store, &iter, 0, "[bluetooth]", -1);
 		} else {
-			menu_item = gtk_menu_item_new_with_label (dev->port);
+			gtk_list_store_set (list_store, &iter, 0, dev->port, -1);
 		}
-		gtk_object_set_data (GTK_OBJECT (menu_item), "device", dev);
-		gtk_widget_show (menu_item);
-		gtk_menu_append (GTK_MENU (menu), menu_item);
 		tmp = tmp->next;
 	}
-	gtk_option_menu_set_menu (GTK_OPTION_MENU (option_menu), menu);
-	gtk_option_menu_set_history (GTK_OPTION_MENU (option_menu), 0);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (device_combo), 0);
 
 	if (GTK_RESPONSE_OK == gtk_dialog_run (GTK_DIALOG (dlg))) {
-		menu_item = gtk_menu_get_active (GTK_MENU (menu));
-		dev = (GPilotDevice *)gtk_object_get_data (GTK_OBJECT (menu_item), "device");
+		index = gtk_combo_box_get_active(GTK_COMBO_BOX(device_combo));
+		dev = g_list_nth_data(state->devices, index);
 	} else {
 		dev = NULL;
 	}
@@ -238,7 +329,12 @@ get_default_pilot (PilotState *state)
 	pilot->pilot_username = g_strdup(g_get_real_name ());
 	pilot->pilot_id = getuid ();
 	pilot->name = next_pilot_name (state);
-	pilot->sync_options.basedir = g_concat_dir_and_file (g_get_home_dir (), pilot->name);
+	pilot->sync_options.basedir = g_build_filename (g_get_home_dir (),
+							pilot->name, NULL);
+#ifdef PILOT_LINK_0_12
+	pilot->pilot_charset =
+	    g_strdup(get_default_pilot_charset());
+#endif
 
 	return pilot;
 }
@@ -249,10 +345,11 @@ get_default_device (PilotState *state)
 	GPilotDevice *device = g_new0 (GPilotDevice, 1);
 	
 	device->name = next_cradle_name (state);
-	device->port = g_strdup ("/dev/pilot");
+	device->port = g_strdup ("usb:");
+	/* XXX */
 	device->speed = speedList[DEFAULT_SPEED_INDEX];
-	device->type = PILOT_DEVICE_SERIAL;
-	device->timeout = 2;
+	device->type = PILOT_DEVICE_USB_VISOR;
+	device->timeout = 0;
 	
 	return device;
 }
@@ -265,7 +362,7 @@ insert_numeric_callback (GtkEditable *editable, const gchar *text,
 	
 	for (i =0; i<len; i++) {
 		if (!isdigit (text[i])) {
-			gtk_signal_emit_stop_by_name (GTK_OBJECT (editable), "insert_text");
+			g_signal_stop_emission_by_name (GTK_OBJECT (editable), "insert_text");
 			return;
 		}
 	}
@@ -282,7 +379,7 @@ insert_username_callback (GtkEditable *editable, const gchar *text,
 	if (*position == 0 && len > 0) {
 		utf8_char = g_utf8_get_char_validated (text, -1);
 		if (!g_unichar_isalpha (utf8_char)) {
-			gtk_signal_emit_stop_by_name (GTK_OBJECT (editable), "insert_text");
+			g_signal_stop_emission_by_name (GTK_OBJECT (editable), "insert_text");
 		}
 	} else {
 		gchar *p = (char *) text; 
@@ -290,7 +387,7 @@ insert_username_callback (GtkEditable *editable, const gchar *text,
 		while (p && *p) {
 			utf8_char = g_utf8_get_char_validated (p, -1);
 			if (!g_unichar_isalnum (utf8_char) && !g_unichar_isspace (utf8_char)) {
-				gtk_signal_emit_stop_by_name (GTK_OBJECT (editable), 
+				g_signal_stop_emission_by_name (GTK_OBJECT (editable), 
 							     "insert_text");
 			}
 			p = g_utf8_find_next_char (p, NULL);
@@ -313,13 +410,13 @@ insert_device_callback (GtkEditable *editable, const gchar *text,
 		    && text[0]!='u'
 #endif
 		    ) {
-			gtk_signal_emit_stop_by_name (GTK_OBJECT (editable), "insert_text");
+			g_signal_stop_emission_by_name (GTK_OBJECT (editable), "insert_text");
 			return;
 		} 
 	} else {
 		for (i =0;i<len;i++)
 			if (!(isalnum (text[i]) || text[i]=='/' || text[i]==':')) {
-				gtk_signal_emit_stop_by_name (GTK_OBJECT (editable), "insert_text");
+				g_signal_stop_emission_by_name (GTK_OBJECT (editable), "insert_text");
 				return;
 			}
 	}
@@ -408,6 +505,7 @@ device_type_to_str (GPilotDeviceType t)
 	case PILOT_DEVICE_USB_VISOR: return _("USB");
 	case PILOT_DEVICE_IRDA:      return _("IrDA");
 	case PILOT_DEVICE_NETWORK:   return _("Network");
+	case PILOT_DEVICE_BLUETOOTH: return _("Bluetooth");
 	default:                     return _("Serial");
 	}
 }
@@ -443,64 +541,91 @@ check_device_info (GPilotDevice* device1, GPilotDevice *device2)
 }
 
 gboolean
-check_base_directory (const gchar *dir_name)
+check_base_directory (const gchar *dir_name, gchar **errstr)
 {
 	gboolean ret = TRUE;
 	/* check basedir validity */
 	
 	if (mkdir (dir_name, 0700) < 0 ) {
 		struct stat buf;
-		gchar *errstr;
 		switch (errno) {
 		case EEXIST: 
 			stat (dir_name, &buf);
 			if (S_ISDIR (buf.st_mode)) {  
 				if (!(buf.st_mode & (S_IRUSR | S_IWUSR |S_IXUSR))) {
-					error_dialog (NULL, _("The specified base directory exists but has the wrong permissions.\n"
-							"Please fix or choose another directory"));
+				    *errstr = g_strdup(_("The specified base directory exists but has the wrong permissions.\n"
+					    "Please fix or choose another directory"));;
 					ret = FALSE;
 				}
 			} else {
-				error_dialog (NULL, _("The specified base directory exists but is not a directory.\n"
+				*errstr = g_strdup (_("The specified base directory exists but is not a directory.\n"
 						"Please make it a directory or choose another directory"));
 				ret = FALSE;
 			}
 			break;
 			
 		case EACCES:
-			error_dialog (NULL, _("It wasn't possible to create the specified base directory.\n"
+		    *errstr = g_strdup(_("It wasn't possible to create the specified base directory.\n"
 					"Please verify the permitions on the specified path or choose another directory"));
 			ret = FALSE;
 			break;
 		case ENOENT:
-			error_dialog (NULL, _("The path specified for the base directory is invalid.\n"
+		    *errstr = g_strdup (_("The path specified for the base directory is invalid.\n"
 					"Please choose another directory"));
 			ret = FALSE;
 			break;
 		default:
-			errstr = strerror (errno);
-			error_dialog (NULL, errstr);
-			ret = FALSE;
+		    *errstr = g_strdup(strerror (errno));
+		    ret = FALSE;
 		}
 	}
 	return ret;
 }
 
+/* Check charset is a valid iconv character set id.
+ * return TRUE if it's valid, or FALSE otherwise.
+ */
+gboolean
+check_pilot_charset (const gchar *charset, gchar **errstr)
+{
+#ifndef PILOT_LINK_0_12
+	return TRUE;
+#else
+	iconv_t cd;
+
+	if (charset == NULL || *charset == '\0')
+		return TRUE;
+	cd = iconv_open(charset, "UTF8");
+        if (cd == (iconv_t)-1) {
+		*errstr = g_strdup (g_strdup_printf(_("`%s' is not a valid character set"
+				  " identifier.\nPlease enter a valid"
+				  " identifier or select from the available"
+			    " options."), charset));
+		
+		return FALSE;
+	}
+
+	iconv_close(cd);
+	return TRUE;
+#endif
+}
+
 void
 read_device_config (GtkObject *object, GPilotDevice* device)
 {
-	GtkWidget *port_entry, *speed_menu, *item, *name_entry;
-	GtkWidget *usb_radio, *irda_radio, *network_radio, *timeout_spinner;
+	GtkWidget *port_entry, *speed_combo, *name_entry;
+	GtkWidget *usb_radio, *irda_radio, *network_radio, *timeout_spinner, *bluetooth_radio;
 
 	g_return_if_fail (device!= NULL);
 
-	port_entry  = gtk_object_get_data (GTK_OBJECT (object), "port_entry");
-	name_entry  = gtk_object_get_data (GTK_OBJECT (object), "name_entry");
-	speed_menu = gtk_object_get_data (GTK_OBJECT (object), "speed_menu");
-	usb_radio = gtk_object_get_data (GTK_OBJECT (object), "usb_radio");
-	irda_radio = gtk_object_get_data (GTK_OBJECT (object), "irda_radio");
-	network_radio = gtk_object_get_data (GTK_OBJECT (object), "network_radio");
-	timeout_spinner = gtk_object_get_data (GTK_OBJECT (object), "timeout_spinner");
+	port_entry  = g_object_get_data (G_OBJECT (object), "port_entry");
+	name_entry  = g_object_get_data (G_OBJECT (object), "name_entry");
+	speed_combo = g_object_get_data (G_OBJECT (object), "speed_combo");
+	usb_radio = g_object_get_data (G_OBJECT (object), "usb_radio");
+	irda_radio = g_object_get_data (G_OBJECT (object), "irda_radio");
+	network_radio = g_object_get_data (G_OBJECT (object), "network_radio");
+	bluetooth_radio = g_object_get_data (G_OBJECT (object), "bluetooth_radio");
+	timeout_spinner = g_object_get_data (G_OBJECT (object), "timeout_spinner");
 
 	if (device->port)
 		g_free (device->port);
@@ -511,9 +636,7 @@ read_device_config (GtkObject *object, GPilotDevice* device)
 	device->name = g_strdup (gtk_entry_get_text (GTK_ENTRY (name_entry)));
 	if (device->name == NULL) device->name = g_strdup ("Cradle"); 
 
-	item = gtk_option_menu_get_menu (GTK_OPTION_MENU (speed_menu));
-	item = gtk_menu_get_active (GTK_MENU (item));
-	device->speed = GPOINTER_TO_INT (gtk_object_get_data (GTK_OBJECT (item), "speed"));
+	device->speed = speed_combo_get_speed(GTK_COMBO_BOX(speed_combo));
 
 	device->type = PILOT_DEVICE_SERIAL;
 	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (usb_radio))) {
@@ -522,6 +645,8 @@ read_device_config (GtkObject *object, GPilotDevice* device)
 		device->type = PILOT_DEVICE_IRDA;
 	} else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (network_radio))) {
 		device->type = PILOT_DEVICE_NETWORK;
+	} else if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (bluetooth_radio))) {
+		device->type = PILOT_DEVICE_BLUETOOTH;
 	}
 	
 	device->timeout = gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (timeout_spinner));
@@ -531,15 +656,21 @@ void
 read_pilot_config (GtkObject *object, GPilotPilot *pilot)
 {
 	GtkWidget *id, *name, *pname, *basedir, *menu;
+#ifdef PILOT_LINK_0_12
+	GtkWidget *charset;
+#endif
 	const gchar *num;
 	gint pilotid;
 	g_return_if_fail (pilot!= NULL);
 
-	id      = gtk_object_get_data (GTK_OBJECT (object), "pilotid");
-	name    = gtk_object_get_data (GTK_OBJECT (object), "username");
-	pname   = gtk_object_get_data (GTK_OBJECT (object), "pilotname");
-	basedir = gtk_object_get_data (GTK_OBJECT (object), "basedir");
-	menu    = gtk_object_get_data (GTK_OBJECT (object), "sync_menu");
+	id      = g_object_get_data (G_OBJECT (object), "pilotid");
+	name    = g_object_get_data (G_OBJECT (object), "username");
+	pname   = g_object_get_data (G_OBJECT (object), "pilotname");
+	basedir = g_object_get_data (G_OBJECT (object), "basedir");
+#ifdef PILOT_LINK_0_12
+	charset = g_object_get_data (G_OBJECT (object), "charset");
+#endif
+	menu    = g_object_get_data (G_OBJECT (object), "sync_menu");
  	
 	num = gtk_entry_get_text (GTK_ENTRY (id));
 	pilotid = strtol (num, NULL, 10);
@@ -556,6 +687,12 @@ read_pilot_config (GtkObject *object, GPilotPilot *pilot)
 	if (pilot->sync_options.basedir) 
 		g_free (pilot->sync_options.basedir);
 	pilot->sync_options.basedir = g_strdup (gtk_entry_get_text (GTK_ENTRY (basedir)));
+
+#ifdef PILOT_LINK_0_12
+	if (pilot->pilot_charset)
+		g_free (pilot->pilot_charset);
+	pilot->pilot_charset = g_strdup (gtk_entry_get_text (GTK_ENTRY (charset)));
+#endif
 }
 
 void 
@@ -566,11 +703,12 @@ save_config_and_restart (GnomePilotClient *gpc, PilotState *state)
 	gnome_pilot_client_reread_config (gpc);
 }
 
+/* returns TRUE if the device passes basic sanity checks,
+ * otherwise, returns FALSE and an error-string in *errstr.
+ */
 gboolean
-check_device_settings (GPilotDevice *device)
-{
-	
-	char *str;
+check_device_settings (GPilotDevice *device, char **errstr)
+{	
 #ifndef WITH_HAL
 	struct stat buf;
 	char *usbdevicesfile_str ="/proc/bus/usb/devices";
@@ -578,11 +716,11 @@ check_device_settings (GPilotDevice *device)
 #endif
 
 #ifdef PILOT_LINK_0_12
+	/* device->port is ignored for network and bluetooth syncs */
 	if (strcmp(device->port, "usb:") == 0 && device->type != PILOT_DEVICE_NETWORK
+	    && device->type != PILOT_DEVICE_BLUETOOTH
 	    && device->type != PILOT_DEVICE_USB_VISOR) {
-		str = g_strdup (_("Device 'usb:' is only valid for devices of type USB"));
-		error_dialog (NULL, str);
-		g_free (str);
+		*errstr = g_strdup (_("Device 'usb:' is only valid for devices of type USB"));
 		return FALSE;
 	}
 #endif
@@ -590,15 +728,14 @@ check_device_settings (GPilotDevice *device)
 	if (device->type == PILOT_DEVICE_SERIAL) {
 		g_message ("checking rw on %s", device->port);
 		if (access (device->port, R_OK|W_OK)) {
-			str = g_strdup_printf ("%s\n%s (%s)\n%s",
+			*errstr = g_strdup_printf ("%s\n%s (%s)\n%s",
 					       _("Read/Write permissions failed on"),
 					       device->name, device->port,
 					       _("Check the permissions on the device and retry"));
-			error_dialog (NULL, str);
-			g_free (str);
 			return FALSE;
 		}
 #ifndef WITH_HAL
+#ifdef linux
 	} else if (device->type == PILOT_DEVICE_USB_VISOR) {
 		/* check sysfs or usbfs is mounted */
 		if(stat(sysfs_dir, &buf) != 0 &&
@@ -606,16 +743,15 @@ check_device_settings (GPilotDevice *device)
 		      stat ("/proc/bus/usb/devices_please-use-sysfs-instead", &buf) != 0) ||
 		    !(S_ISREG(buf.st_mode)) ||
 		    !(buf.st_mode & S_IRUSR))) {
-			str = g_strdup_printf (
+			*errstr = g_strdup_printf (
 			    _("Failed to find directory %s or read file %s.  "
 				"Check that usbfs or sysfs is mounted."),
 			    sysfs_dir,
 			    usbdevicesfile_str);
-			error_dialog (NULL, str);
-			g_free (str);
 			return FALSE;
 		}
-#endif
+#endif /* linux */
+#endif /* !WITH_HAL */
 	} 
 
 	return TRUE;
