@@ -22,15 +22,16 @@
  *
  */
 
-#include <gnome.h>
 #include <gpilotd/gnome-pilot-client.h>
 #include "pilot.h"
 
 /* Gui routines */
-void fill_speed_menu (GtkOptionMenu *optionMenu, guint default_speed);
-void fill_synctype_menu (GtkOptionMenu *optionMenu, GnomePilotConduitSyncType type);
-void fill_conduit_sync_type_menu (GtkOptionMenu *option_menu, ConduitState *state);
-void fill_conduit_first_sync_type_menu (GtkOptionMenu *option_menu, ConduitState *state);
+void fill_speed_combo (GtkComboBox *option_combo);
+int speed_combo_get_speed (GtkComboBox *option_combo);
+gboolean speed_combo_set_speed (GtkComboBox *option_combo, int speed);
+
+void fill_conduit_sync_type_combo (GtkComboBox *option_combo, ConduitState *state);
+void fill_conduit_first_sync_type_combo (GtkComboBox *option_combo, ConduitState *state);
 gboolean show_popup_menu (GtkTreeView *treeview, GdkEventButton *event, GtkMenu *menu);
 
 /* Filtering callbacks */
@@ -54,11 +55,12 @@ gchar *next_pilot_name (PilotState *state);
 const gchar* sync_type_to_str (GnomePilotConduitSyncType t);
 const gchar* device_type_to_str (GPilotDeviceType t);
 const gchar* display_sync_type_name (gboolean enabled, GnomePilotConduitSyncType sync_type);
+int speedlist_int_to_index (int speed);
 
 gboolean check_pilot_info (GPilotPilot* pilot1, GPilotPilot *pilot2);
 gboolean check_device_info (GPilotDevice* device1, GPilotDevice *device2);
-gboolean check_base_directory (const gchar *dir_name);
-gboolean check_pilot_charset (const gchar *charset);
+gboolean check_base_directory (const gchar *dir_name, gchar **errstr);
+gboolean check_pilot_charset (const gchar *charset, gchar **errstr);
 
 /* Dialogs */
 void error_dialog (GtkWindow *parent, gchar *mesg, ...);
@@ -70,4 +72,4 @@ void read_pilot_config (GtkObject *object, GPilotPilot *pilot);
 
 void save_config_and_restart (GnomePilotClient *gpc, PilotState *state);
 
-gboolean check_device_settings (GPilotDevice *device);
+gboolean check_device_settings (GPilotDevice *device, char **errstr);
