@@ -21,7 +21,7 @@
  *          Robert Mibus
  */
 
-/* $Id: backup_conduit.h 1381 2006-03-13 22:40:56Z mcdavey $ */
+/* $Id$ */
 #ifndef __BACKUP_CONDUIT_H__
 #define __BACKUP_CONDUIT_H__
 
@@ -34,7 +34,6 @@
 #define OBJ_DATA_CONFIG  "conduit_config"
 #define OBJ_DATA_OLDCONFIG  "conduit_oldconfig"
 #define OBJ_DATA_CONFIG_WINDOW  "config_window"
-#define CONFIG_PREFIX    "/gnome-pilot.d/backup-conduit/Pilot_%u/"
 
 typedef struct ConduitCfg {
   gchar *backup_dir;
@@ -49,9 +48,9 @@ typedef struct ConduitCfg {
   pid_t child;
 } ConduitCfg;
 
-#define GET_CONDUIT_CFG(s) ((ConduitCfg*)gtk_object_get_data(GTK_OBJECT(s),OBJ_DATA_CONFIG))
-#define GET_CONDUIT_OLDCFG(s) ((ConduitCfg*)gtk_object_get_data(GTK_OBJECT(s),OBJ_DATA_OLDCONFIG))
-#define GET_CONDUIT_DATA(s) ((ConduitData*)gtk_object_get_data(GTK_OBJECT(s),OBJ_DATA_CONDUIT))
-#define GET_CONDUIT_WINDOW(s) ((GtkWidget*)gtk_object_get_data(GTK_OBJECT(s),OBJ_DATA_CONFIG_WINDOW))
+#define GET_CONDUIT_CFG(s) ((ConduitCfg*)g_object_get_data(G_OBJECT(s),OBJ_DATA_CONFIG))
+#define GET_CONDUIT_OLDCFG(s) ((ConduitCfg*)g_object_get_data(G_OBJECT(s),OBJ_DATA_OLDCONFIG))
+#define GET_CONDUIT_DATA(s) ((ConduitData*)g_object_get_data(G_OBJECT(s),OBJ_DATA_CONDUIT))
+#define GET_CONDUIT_WINDOW(s) ((GtkWidget*)g_object_get_data(G_OBJECT(s),OBJ_DATA_CONFIG_WINDOW))
 
 #endif
