@@ -20,13 +20,13 @@
  *          Vadim Strizhevsky
  */
 
-/* $Id: file_conduit.c 1503 2007-05-12 20:07:09Z mcdavey $ */
+/* $Id$ */
 
 #include <glib.h>
-#include <gnome.h>
-
+#include <glib/gi18n.h>
 #include <pi-source.h>
 #include <pi-socket.h>
+#include <stdio.h>
 #include <pi-file.h>
 #include <pi-dlp.h>
 #include <pi-version.h>
