@@ -20,31 +20,29 @@
  */
 
 #include "config.h"
-#include <gnome.h>
+#include <gtk/gtk.h>
+#include <glib/gi18n-lib.h>
+
 #include <gpilotd/gnome-pilot-client.h>
 
-#include <bonobo.h>
-#include <bonobo-activation/bonobo-activation.h>
-
-
-
 GnomePilotClient *gpc;
-CORBA_Environment ev;
 GSList *handles;
 GSList *failed,*notfailed;
 int handle;
 GtkWidget *dialog;
 
 
-int now = 0, later = 0;
+gboolean now = FALSE, later = FALSE;
 char *debug_modules = NULL;
-char *pilot_arg=NULL;
+gchar *pilot_arg=NULL;
+gchar **filenames;
 
-static const struct poptOption options[] = {
-	{"now", 'n', POPT_ARG_NONE, &now, 0, N_("Install immediately"), NULL},
-	{"later", 'l', POPT_ARG_NONE, &later, 0, N_("Install delayed"), NULL},
-	{"pilot", 'p', POPT_ARG_STRING, &pilot_arg, 0, N_("PDA to install to"), N_("PDA")},
-	{NULL, '\0', 0, NULL, 0} /* end the list */
+static GOptionEntry options[] = {
+	{"now", 'n', 0, G_OPTION_ARG_NONE, &now, N_("Install immediately"), NULL},
+	{"later", 'l', 0, G_OPTION_ARG_NONE, &later, N_("Install delayed"), NULL},
+	{"pilot", 'p', 0, G_OPTION_ARG_STRING, &pilot_arg, N_("PDA to install to"), N_("PDA")},
+	{G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &filenames, N_("[FILE...]"), N_("list of files")},
+	{NULL}
 };
 
 static void 
@@ -52,20 +50,10 @@ gpilotd_request_completed (GnomePilotClient *gpc, gchar *pilot_id, gint handle,
 {
 	g_message ("%s completed %d", pilot_id, handle);
 	handles = g_slist_remove (handles,GINT_TO_POINTER(handle));
-	if (handles == NULL)
-		gnome_dialog_close (GNOME_DIALOG (dialog));
-}
-
-static void 
-cancel_install (GnomeDialog *w, GSList *list) 
-{
-	GSList *e;
-
-	for (e=list;e;e = g_slist_next (e)) {
-		gnome_pilot_client_remove_request (gpc,GPOINTER_TO_INT(e->data));  
+	if (handles == NULL) {
+		gtk_widget_destroy (dialog);
+		dialog = NULL;
 	}
-	g_slist_free (list);
-
 }
 
 static void 
@@ -76,9 +64,11 @@ show_warning_dialog (gchar *mesg,...)
 	va_start (ap, mesg);
 
 	tmp = g_strdup_vprintf (mesg, ap);
-	dialog = gnome_message_box_new (tmp, GNOME_MESSAGE_BOX_WARNING,
-				       GNOME_STOCK_BUTTON_OK, NULL);
-	gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
+	dialog = gtk_message_dialog_new (NULL, 0,GTK_MESSAGE_WARNING,
+	    GTK_BUTTONS_OK, "%s", tmp);
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
+	dialog = NULL;
 	g_free (tmp);
 	va_end (ap);
 }
@@ -88,26 +78,31 @@ main (int argc, char *argv[])
 {
 	int err, i;
 	GNOME_Pilot_Survival survive;
-        poptContext pctx;
+	GError *error;
 	GList *pilots = NULL;
-        const char **args;
+	GOptionContext *option_context;
         
 	bindtextdomain (PACKAGE, GNOMELOCALEDIR);
 	textdomain (PACKAGE);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 
 	if (argc<2) {
-		g_message ("usage : %s [--now|--later] [FILE]", argv[0]);
+		g_message ("usage : %s [--now|--later] [--pilot PDA] [FILE ...]", argv[0]);
 		exit (1);
 	}
 
-	gnome_init_with_popt_table ("gpilotd-install-file", "1.0",
-				    argc, argv, options, 0, &pctx);
-	
+	option_context = g_option_context_new (PACKAGE);
+	g_option_context_add_main_entries (option_context, options, NULL);
+	if (!g_option_context_parse(option_context, &argc, &argv, &error)) {
+		g_error (_("Error parsing commandline arguments: %s"), error->message);
+		exit (1);
+	}
+
+	gtk_init (&argc, &argv);
+
 	gpc = GNOME_PILOT_CLIENT (gnome_pilot_client_new ());
-	gtk_object_ref (GTK_OBJECT (gpc));
-	gtk_object_sink (GTK_OBJECT (gpc));
-	gtk_signal_connect (GTK_OBJECT (gpc),"completed_request", (GtkSignalFunc)gpilotd_request_completed, NULL);
+	g_object_ref_sink (G_OBJECT (gpc));
+	g_signal_connect (GTK_OBJECT (gpc),"completed_request", G_CALLBACK(gpilotd_request_completed), NULL);
 	gnome_pilot_client_connect_to_daemon (gpc);
 
 	if (pilot_arg!=NULL) {
@@ -128,27 +123,23 @@ main (int argc, char *argv[])
 	
 	i=0;
 
-        args = poptGetArgs (pctx);
-
-	while (args && args[i]!=NULL) {
+	while (filenames && filenames[i]!=NULL) {
 		gint err;
 		err = gnome_pilot_client_install_file (gpc,
 						       pilots->data, /* get first pilot */
-						       args[i],
+						       filenames[i],
 						       survive,
 						       0,
 						       &handle);
 		if (err == GPILOTD_OK) {
 			handles = g_slist_prepend (handles,GINT_TO_POINTER(handle));
-			notfailed = g_slist_prepend (notfailed, (void *) args[i]);
+			notfailed = g_slist_prepend (notfailed, (void *) filenames[i]);
 		} else {
-			failed = g_slist_prepend (failed, (void *) args[i]);
+			failed = g_slist_prepend (failed, (void *) filenames[i]);
 		}
 		i++;
 	}
 
-        poptFreeContext (pctx);
-
 	if (!later) {
 		gchar *message;
 		
@@ -193,14 +184,13 @@ main (int argc, char *argv[])
 				
 				info = g_strdup (_("Press synchronize on the cradle to install\n" 
 						  " or cancel the operation."));
-				GNOME_Pilot_Daemon_request_conduit (gpc->gpilotddaemon,
-								    gpc->gpilotdclient,
-								    pilots->data,
-								    "File",
-								    GNOME_Pilot_CONDUIT_DEFAULT,
-								    survive,
-								    0,
-								    &ev);
+                                err = gnome_pilot_client_conduit (gpc,
+                                                            pilots->data,
+                                                            "File",
+                                                            GNOME_Pilot_CONDUIT_DEFAULT,
+                                                            survive,
+                                                            0,
+                                                            &handle);
 			}
 						
 			tmp = g_strconcat (message==NULL?"":message,
@@ -211,17 +201,24 @@ main (int argc, char *argv[])
 			g_free (info);
 			message = tmp;
 		}
-		dialog = gnome_message_box_new (message,
-					       GNOME_MESSAGE_BOX_GENERIC,
-					       GNOME_STOCK_BUTTON_CANCEL,
-					       NULL);
-		gnome_dialog_button_connect (GNOME_DIALOG (dialog),0,
-					    G_CALLBACK(cancel_install), handles);
-		gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
+		dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
+		    GTK_MESSAGE_OTHER, GTK_BUTTONS_CANCEL, "%s",
+		    message);
+		gint response = gtk_dialog_run(GTK_DIALOG(dialog));
+		if (dialog != NULL) /* if not destroyed by callback */
+			gtk_widget_destroy(dialog);
+		if (response == GTK_RESPONSE_CANCEL) {
+			GSList *e;
+			for (e=handles;e;e = g_slist_next (e)) {
+				gnome_pilot_client_remove_request
+				    (gpc,GPOINTER_TO_INT(e->data));  
+			}
+			g_slist_free (handles);
+		}
 		g_free (message);
 	}
 
-	gtk_object_unref (GTK_OBJECT (gpc));
+	g_object_unref (G_OBJECT (gpc));
 
 	return 0;
 }
