@@ -27,7 +27,8 @@
 #include <config.h>
 #endif
 
-#include <gnome.h>
+#include <glib/gi18n.h>
+
 #include <pi-source.h>
 #include <pi-socket.h>
 #include <pi-dlp.h>
@@ -177,26 +178,29 @@ void standard_abs_close_db_and_purge_local(GnomePilotConduitStandardAbs*,GnomePi
 static GnomePilotConduitStandardClass *parent_class = NULL;
 static guint pilot_conduit_standard_abs_signals[LAST_SIGNAL] = { 0 };
 
-GtkType
+GType
 gnome_pilot_conduit_standard_abs_get_type (void)
 {
-	static GtkType pilot_conduit_standard_abs_type = 0;
+	static GType pilot_conduit_standard_abs_type = 0;
 
 	if (!pilot_conduit_standard_abs_type)
 	{
-		static const GtkTypeInfo pilot_conduit_standard_abs_info =
+		static const GTypeInfo pilot_conduit_standard_abs_info =
 		{
-			"GnomePilotConduitStandardAbs",
-			sizeof (GnomePilotConduitStandardAbs),
 			sizeof (GnomePilotConduitStandardAbsClass),
-			(GtkClassInitFunc) gnome_pilot_conduit_standard_abs_class_init,
-			(GtkObjectInitFunc) gnome_pilot_conduit_standard_abs_init,
-			/* reserved_1 */ NULL,
-			/* reserved_2 */ NULL,
-			(GtkClassInitFunc) NULL,
+			NULL,
+			NULL,
+			(GClassInitFunc) gnome_pilot_conduit_standard_abs_class_init,
+			NULL,
+			NULL,
+			sizeof (GnomePilotConduitStandardAbs),
+			0,
+			(GInstanceInitFunc) gnome_pilot_conduit_standard_abs_init,
 		};
 
-		pilot_conduit_standard_abs_type = gtk_type_unique (gnome_pilot_conduit_standard_get_type (), &pilot_conduit_standard_abs_info);
+		pilot_conduit_standard_abs_type = g_type_register_static (
+		    gnome_pilot_conduit_standard_get_type (),
+		    "GnomePilotConduitStandardAbs", &pilot_conduit_standard_abs_info, 0);
 	}
 
 	return pilot_conduit_standard_abs_type;
@@ -208,7 +212,7 @@ gnome_pilot_conduit_standard_abs_new (char *db_name,
 {
 	GtkObject *retval;
 
-	retval =  gtk_object_new (gnome_pilot_conduit_standard_abs_get_type (),
+	retval =  g_object_new (gnome_pilot_conduit_standard_abs_get_type (),
 				  "GnomePilotConduitStandard::db_name", db_name,
 				  "GnomePilotConduitStandard::creator_id", creator_id,
 				  NULL);
@@ -225,135 +229,167 @@ gnome_pilot_conduit_standard_abs_class_init (GnomePilotConduitStandardAbsClass *
 	object_class = (GtkObjectClass*) klass;
 	conduit_standard_class = (GnomePilotConduitStandardClass *) klass;
 
-	parent_class = gtk_type_class (gnome_pilot_conduit_standard_get_type ());
+	parent_class = g_type_class_peek (gnome_pilot_conduit_standard_get_type ());
 
 	pilot_conduit_standard_abs_signals[MATCH_RECORD] =
-		gtk_signal_new ("match_record",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, match_record),
+		g_signal_new   ("match_record",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitStandardAbsClass, match_record),
+				NULL,
+				NULL,
 				gp_marshal_INT__POINTER_POINTER,
-				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
+				G_TYPE_INT, 2, G_TYPE_POINTER, G_TYPE_POINTER);
 
 	pilot_conduit_standard_abs_signals[FREE_MATCH] =
-		gtk_signal_new ("free_match",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, free_match),
+		g_signal_new   ("free_match",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitStandardAbsClass, free_match),
+				NULL,
+				NULL,
 				gp_marshal_INT__POINTER,
-				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
+				G_TYPE_INT, 1, G_TYPE_POINTER);
 
 	pilot_conduit_standard_abs_signals[ARCHIVE_LOCAL] =
-		gtk_signal_new ("archive_local",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, archive_local),
+		g_signal_new   ("archive_local",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitStandardAbsClass, archive_local),
+				NULL,
+				NULL,
 				gp_marshal_INT__POINTER,
-				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
+				G_TYPE_INT, 1, G_TYPE_POINTER);
 
 	pilot_conduit_standard_abs_signals[ARCHIVE_REMOTE] =
-		gtk_signal_new ("archive_remote",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, archive_remote),
+		g_signal_new   ("archive_remote",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitStandardAbsClass, archive_remote),
+				NULL,
+				NULL,
 				gp_marshal_INT__POINTER_POINTER,
-				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
+				G_TYPE_INT, 2, G_TYPE_POINTER, G_TYPE_POINTER);
 
 	pilot_conduit_standard_abs_signals[STORE_REMOTE] =
-		gtk_signal_new ("store_remote",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, store_remote),
+		g_signal_new   ("store_remote",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitStandardAbsClass, store_remote),
+				NULL,
+				NULL,
 				gp_marshal_INT__POINTER,
-				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
+				G_TYPE_INT, 1, G_TYPE_POINTER);
 
 	pilot_conduit_standard_abs_signals[ITERATE] =
-		gtk_signal_new ("iterate",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, iterate),
+		g_signal_new   ("iterate",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitStandardAbsClass, iterate),
+				NULL,
+				NULL,
 				gp_marshal_INT__POINTER,
-				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
+				G_TYPE_INT, 1, G_TYPE_POINTER);
 
 	pilot_conduit_standard_abs_signals[ITERATE_SPECIFIC] =
-		gtk_signal_new ("iterate_specific",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, iterate_specific),
+		g_signal_new   ("iterate_specific",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitStandardAbsClass, iterate_specific),
+				NULL,
+				NULL,
 				gp_marshal_INT__POINTER_INT_INT,
-				GTK_TYPE_INT, 3, GTK_TYPE_POINTER, GTK_TYPE_INT, GTK_TYPE_INT);
+				G_TYPE_INT, 3, G_TYPE_POINTER, G_TYPE_INT, G_TYPE_INT);
 
 	pilot_conduit_standard_abs_signals[PURGE] =
-		gtk_signal_new ("purge",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, purge),
+		g_signal_new   ("purge",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitStandardAbsClass, purge),
+				NULL,
+				NULL,
 				gp_marshal_INT__NONE,
-				GTK_TYPE_INT, 0);
+				G_TYPE_INT, 0);
 
 	pilot_conduit_standard_abs_signals[SET_STATUS] =
-		gtk_signal_new ("set_status",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, set_status),
+		g_signal_new   ("set_status",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitStandardAbsClass, set_status),
+				NULL,
+				NULL,
 				gp_marshal_INT__POINTER_INT,
-				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_INT);
+				G_TYPE_INT, 2, G_TYPE_POINTER, G_TYPE_INT);
 
 	pilot_conduit_standard_abs_signals[SET_PILOT_ID] =
-		gtk_signal_new ("set_pilot_id",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, set_pilot_id),
+		g_signal_new   ("set_pilot_id",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitStandardAbsClass, set_pilot_id),
+				NULL,
+				NULL,
 				gp_marshal_INT__POINTER_INT,
-				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_INT);
+				G_TYPE_INT, 2, G_TYPE_POINTER, G_TYPE_INT);
 
 	pilot_conduit_standard_abs_signals[COMPARE] =
-		gtk_signal_new ("compare",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, compare),
+		g_signal_new   ("compare",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitStandardAbsClass, compare),
+				NULL,
+				NULL,
 				gp_marshal_INT__POINTER_POINTER,
-				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
+				G_TYPE_INT, 2, G_TYPE_POINTER, G_TYPE_POINTER);
 
 	pilot_conduit_standard_abs_signals[COMPARE_BACKUP] =
-		gtk_signal_new ("compare_backup",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, compare_backup),
+		g_signal_new   ("compare_backup",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitStandardAbsClass, compare_backup),
+				NULL,
+				NULL,
 				gp_marshal_INT__POINTER_POINTER,
-				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
+				G_TYPE_INT, 2, G_TYPE_POINTER, G_TYPE_POINTER);
 
 	pilot_conduit_standard_abs_signals[FREE_TRANSMIT] =
-		gtk_signal_new ("free_transmit",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, free_transmit),
+		g_signal_new   ("free_transmit",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitStandardAbsClass, free_transmit),
+				NULL,
+				NULL,
 				gp_marshal_INT__POINTER_POINTER,
-				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
+				G_TYPE_INT, 2, G_TYPE_POINTER, G_TYPE_POINTER);
 
 	pilot_conduit_standard_abs_signals[DELETE_ALL] =
-		gtk_signal_new ("delete_all",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, delete_all),
+		g_signal_new   ("delete_all",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitStandardAbsClass, delete_all),
+				NULL,
+				NULL,
 				gp_marshal_INT__NONE,
-				GTK_TYPE_INT, 0);
+				G_TYPE_INT, 0);
 
 	pilot_conduit_standard_abs_signals[TRANSMIT] =
-		gtk_signal_new ("transmit",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, transmit),
+		g_signal_new   ("transmit",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitStandardAbsClass, transmit),
+				NULL,
+				NULL,
 				gp_marshal_INT__POINTER_POINTER,
-				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
+				G_TYPE_INT, 2, G_TYPE_POINTER, G_TYPE_POINTER);
 
 	pilot_conduit_standard_abs_signals[PRE_SYNC] =
-		gtk_signal_new ("pre_sync",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitStandardAbsClass, pre_sync),
+		g_signal_new   ("pre_sync",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitStandardAbsClass, pre_sync),
+				NULL,
+				NULL,
 				gp_marshal_INT__POINTER,
-				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
+				G_TYPE_INT, 1, G_TYPE_POINTER);
 
 	conduit_standard_class->copy_to_pilot = gnome_pilot_conduit_standard_real_copy_to_pilot;
 	conduit_standard_class->copy_from_pilot = gnome_pilot_conduit_standard_real_copy_from_pilot;
@@ -675,8 +711,9 @@ gnome_pilot_conduit_standard_abs_match_record (GnomePilotConduitStandardAbs *con
 	g_return_val_if_fail (conduit != NULL, -1);
 	g_return_val_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit), -1);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_standard_abs_signals [MATCH_RECORD],
+			 0,
 			 local,
 			 remote,
 			 &retval);
@@ -693,8 +730,9 @@ gnome_pilot_conduit_standard_abs_free_match (GnomePilotConduitStandardAbs *condu
 	g_return_val_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit), -1);
 
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_standard_abs_signals [FREE_MATCH],
+			 0,
 			 local,
 			 &retval);
 	return retval;
@@ -709,8 +747,9 @@ gnome_pilot_conduit_standard_abs_archive_local (GnomePilotConduitStandardAbs *co
 	g_return_val_if_fail (conduit != NULL, -1);
 	g_return_val_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit), -1);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_standard_abs_signals [ARCHIVE_LOCAL],
+			 0,
 			 local,
 			 &retval);
 	return retval;
@@ -726,8 +765,9 @@ gnome_pilot_conduit_standard_abs_archive_remote (GnomePilotConduitStandardAbs *c
 	g_return_val_if_fail (conduit != NULL, -1);
 	g_return_val_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit), -1);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_standard_abs_signals [ARCHIVE_REMOTE],
+			 0,
 			 local,
 			 remote,
 			 &retval);
@@ -743,8 +783,9 @@ gnome_pilot_conduit_standard_abs_store_remote (GnomePilotConduitStandardAbs *con
 	g_return_val_if_fail (conduit != NULL, -1);
 	g_return_val_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit), -1);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_standard_abs_signals [STORE_REMOTE],
+			 0,
 			 remote,
 			 &retval);
 	return retval;
@@ -760,8 +801,9 @@ gnome_pilot_conduit_standard_abs_iterate (GnomePilotConduitStandardAbs *conduit,
 	g_return_val_if_fail (conduit != NULL, -1);
 	g_return_val_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit), -1);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_standard_abs_signals [ITERATE],
+			 0,
 			 local,
 			 &retval);
 	return retval;
@@ -778,8 +820,9 @@ gnome_pilot_conduit_standard_abs_iterate_specific (GnomePilotConduitStandardAbs
 	g_return_val_if_fail (conduit != NULL, -1);
 	g_return_val_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit), -1);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_standard_abs_signals [ITERATE_SPECIFIC],
+			 0,
 			 local,
 			 flag,
 			 archived,
@@ -795,8 +838,9 @@ gnome_pilot_conduit_standard_abs_purge (GnomePilotConduitStandardAbs *conduit)
 	g_return_val_if_fail (conduit != NULL, -1);
 	g_return_val_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit), -1);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_standard_abs_signals [PURGE],
+			 0,
 			 &retval);
 	return retval;
 }
@@ -811,8 +855,9 @@ gnome_pilot_conduit_standard_abs_set_status (GnomePilotConduitStandardAbs *condu
 	g_return_val_if_fail (conduit != NULL, -1);
 	g_return_val_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit), -1);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_standard_abs_signals [SET_STATUS],
+			 0,
 			 local,
 			 status,
 			 &retval);
@@ -830,8 +875,9 @@ gnome_pilot_conduit_standard_abs_set_pilot_id (GnomePilotConduitStandardAbs *con
 	g_return_val_if_fail (conduit != NULL, -1);
 	g_return_val_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit), -1);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_standard_abs_signals [SET_PILOT_ID],
+			 0,
 			 local,
 			 id,
 			 &retval);
@@ -848,8 +894,9 @@ gnome_pilot_conduit_standard_abs_compare (GnomePilotConduitStandardAbs *conduit,
 	g_return_val_if_fail (conduit != NULL, -1);
 	g_return_val_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit), -1);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_standard_abs_signals [COMPARE],
+			 0,
 			 local,
 			 remote,
 			 &retval);
@@ -866,8 +913,9 @@ gnome_pilot_conduit_standard_abs_compare_backup (GnomePilotConduitStandardAbs *c
 	g_return_val_if_fail (conduit != NULL, -1);
 	g_return_val_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit), -1);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_standard_abs_signals [COMPARE_BACKUP],
+			 0,
 			 local,
 			 remote,
 			 &retval);
@@ -884,8 +932,9 @@ gnome_pilot_conduit_standard_abs_free_transmit (GnomePilotConduitStandardAbs *co
 	g_return_val_if_fail (conduit != NULL, -1);
 	g_return_val_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit), -1);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_standard_abs_signals [FREE_TRANSMIT],
+			 0,
 			 local,
 			 remote,
 			 &retval);
@@ -901,8 +950,9 @@ gnome_pilot_conduit_standard_abs_delete_all (GnomePilotConduitStandardAbs *condu
 	g_return_val_if_fail (conduit != NULL, -1);
 	g_return_val_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit), -1);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_standard_abs_signals [DELETE_ALL],
+			 0,
 			 &retval);
 	return retval;
 }
@@ -917,8 +967,9 @@ gnome_pilot_conduit_standard_abs_transmit (GnomePilotConduitStandardAbs *conduit
 	g_return_val_if_fail (conduit != NULL, -1);
 	g_return_val_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit), -1);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_standard_abs_signals [TRANSMIT],
+			 0,
 			 local,
 			 remote,
 			 &retval);
@@ -935,8 +986,9 @@ gnome_pilot_conduit_standard_abs_pre_sync (GnomePilotConduitStandardAbs *conduit
 	g_return_val_if_fail (dbinfo != NULL, -1);
 	g_return_val_if_fail (GNOME_IS_PILOT_CONDUIT_STANDARD_ABS (conduit), -1);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_standard_abs_signals [PRE_SYNC],
+			 0,
 			 dbinfo,
 			 &retval);
 	return retval;
