@@ -24,7 +24,7 @@
  *
  */
 
-#include <gnome.h>
+#include <glib/gi18n.h>
 #include <pi-source.h>
 #include <pi-socket.h>
 #include <pi-dlp.h>
@@ -101,26 +101,28 @@ static gboolean gpilot_sync_pc_match (GnomePilotDBInfo *);
 static GnomePilotConduitStandardClass *parent_class = NULL;
 static guint pilot_conduit_sync_abs_signals[LAST_SIGNAL] = { 0 };
 
-GtkType
+GType
 gnome_pilot_conduit_sync_abs_get_type (void)
 {
-	static GtkType pilot_conduit_sync_abs_type = 0;
+	static GType pilot_conduit_sync_abs_type = 0;
 
 	if (!pilot_conduit_sync_abs_type)
 	{
-		static const GtkTypeInfo pilot_conduit_sync_abs_info =
+		static const GTypeInfo pilot_conduit_sync_abs_info =
 		{
-			"GnomePilotConduitSyncAbs",
-			sizeof (GnomePilotConduitSyncAbs),
 			sizeof (GnomePilotConduitSyncAbsClass),
-			(GtkClassInitFunc) gnome_pilot_conduit_sync_abs_class_init,
-			(GtkObjectInitFunc) gnome_pilot_conduit_sync_abs_init,
-			/* reserved_1 */ NULL,
-			/* reserved_2 */ NULL,
-			(GtkClassInitFunc) NULL,
+			NULL,
+			NULL,
+			(GClassInitFunc) gnome_pilot_conduit_sync_abs_class_init,
+			NULL,
+			NULL,
+			sizeof (GnomePilotConduitSyncAbs),
+			0,
+			(GInstanceInitFunc) gnome_pilot_conduit_sync_abs_init,
 		};
-
-		pilot_conduit_sync_abs_type = gtk_type_unique (gnome_pilot_conduit_standard_get_type (), &pilot_conduit_sync_abs_info);
+		pilot_conduit_sync_abs_type = g_type_register_static (
+		    gnome_pilot_conduit_standard_get_type (),
+			"GnomePilotConduitSyncAbs", &pilot_conduit_sync_abs_info, 0);
 	}
 
 	return pilot_conduit_sync_abs_type;
@@ -135,121 +137,149 @@ gnome_pilot_conduit_sync_abs_class_init (GnomePilotConduitSyncAbsClass *klass)
 	object_class = (GtkObjectClass*) klass;
 	conduit_standard_class = (GnomePilotConduitStandardClass *) klass;
 
-	parent_class = gtk_type_class (gnome_pilot_conduit_standard_get_type ());
+	parent_class = g_type_class_peek (gnome_pilot_conduit_standard_get_type ());
 
 	pilot_conduit_sync_abs_signals[PRE_SYNC] =
-		gtk_signal_new ("pre_sync",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, pre_sync),
-				gtk_marshal_INT__POINTER,
-				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
+		g_signal_new   ("pre_sync",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitSyncAbsClass, pre_sync),
+				NULL,
+				NULL,
+				gp_marshal_INT__POINTER,
+				G_TYPE_INT, 1, G_TYPE_POINTER);
 
 	pilot_conduit_sync_abs_signals[POST_SYNC] =
-		gtk_signal_new ("post_sync",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, pre_sync),
-				gtk_marshal_INT__POINTER,
-				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
+		g_signal_new   ("post_sync",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitSyncAbsClass, post_sync),
+				NULL,
+				NULL,
+				gp_marshal_INT__POINTER,
+				G_TYPE_INT, 1, G_TYPE_POINTER);
 
 
 	pilot_conduit_sync_abs_signals[SET_PILOT_ID] =
-		gtk_signal_new ("set_pilot_id",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, set_pilot_id),
+		g_signal_new   ("set_pilot_id",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitSyncAbsClass, set_pilot_id),
+				NULL,
+				NULL,
 				gp_marshal_INT__POINTER_INT,
-				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_INT);
+				G_TYPE_INT, 2, G_TYPE_POINTER, G_TYPE_INT);
 
 
 	pilot_conduit_sync_abs_signals[SET_STATUS_CLEARED] =
-		gtk_signal_new ("set_status_cleared",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, set_status_cleared),
-				gtk_marshal_INT__POINTER,
-				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
+		g_signal_new   ("set_status_cleared",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitSyncAbsClass, set_status_cleared),
+				NULL,
+				NULL,
+				gp_marshal_INT__POINTER,
+				G_TYPE_INT, 1, G_TYPE_POINTER);
 
 	pilot_conduit_sync_abs_signals[FOR_EACH] =
-		gtk_signal_new ("for_each",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, for_each),
-				gtk_marshal_INT__POINTER,
-				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
+		g_signal_new   ("for_each",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitSyncAbsClass, for_each),
+				NULL,
+				NULL,
+				gp_marshal_INT__POINTER,
+				G_TYPE_INT, 1, G_TYPE_POINTER);
 
 	pilot_conduit_sync_abs_signals[FOR_EACH_MODIFIED] =
-		gtk_signal_new ("for_each_modified",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, for_each_modified),
-				gtk_marshal_INT__POINTER,
-				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
+		g_signal_new   ("for_each_modified",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitSyncAbsClass, for_each_modified),
+				NULL,
+				NULL,
+				gp_marshal_INT__POINTER,
+				G_TYPE_INT, 1, G_TYPE_POINTER);
 
 	pilot_conduit_sync_abs_signals[COMPARE] =
-		gtk_signal_new ("compare",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, compare),
+		g_signal_new   ("compare",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitSyncAbsClass, compare),
+				NULL,
+				NULL,
 				gp_marshal_INT__POINTER_POINTER,
-				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
+				G_TYPE_INT, 2, G_TYPE_POINTER, G_TYPE_POINTER);
 
 	pilot_conduit_sync_abs_signals[ADD_RECORD] =
-		gtk_signal_new ("add_record",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, add_record),
-				gtk_marshal_INT__POINTER,
-				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
+		g_signal_new   ("add_record",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitSyncAbsClass, add_record),
+				NULL,
+				NULL,
+				gp_marshal_INT__POINTER,
+				G_TYPE_INT, 1, G_TYPE_POINTER);
 
 	pilot_conduit_sync_abs_signals[REPLACE_RECORD] =
-		gtk_signal_new ("replace_record",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, replace_record),
+		g_signal_new   ("replace_record",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitSyncAbsClass, replace_record),
+				NULL,
+				NULL,
 				gp_marshal_INT__POINTER_POINTER,
-				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
+				G_TYPE_INT, 2, G_TYPE_POINTER, G_TYPE_POINTER);
 
 	pilot_conduit_sync_abs_signals[DELETE_RECORD] =
-		gtk_signal_new ("delete_record",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, delete_record),
-				gtk_marshal_INT__POINTER,
-				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
+		g_signal_new   ("delete_record",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitSyncAbsClass, delete_record),
+				NULL,
+				NULL,
+				gp_marshal_INT__POINTER,
+				G_TYPE_INT, 1, G_TYPE_POINTER);
 
 	pilot_conduit_sync_abs_signals[ARCHIVE_RECORD] =
-		gtk_signal_new ("archive_record",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, archive_record),
+		g_signal_new   ("archive_record",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitSyncAbsClass, archive_record),
+				NULL,
+				NULL,
 				gp_marshal_INT__POINTER_BOOL,
-				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_BOOL);
+				G_TYPE_INT, 2, G_TYPE_POINTER, G_TYPE_BOOLEAN);
 
 	pilot_conduit_sync_abs_signals[MATCH] =
-		gtk_signal_new ("match",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, match),
+		g_signal_new   ("match",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitSyncAbsClass, match),
+				NULL,
+				NULL,
 				gp_marshal_INT__POINTER_POINTER,
-				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
+				G_TYPE_INT, 2, G_TYPE_POINTER, G_TYPE_POINTER);
 
 	pilot_conduit_sync_abs_signals[FREE_MATCH] =
-		gtk_signal_new ("free_match",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, free_match),
-				gtk_marshal_INT__POINTER,
-				GTK_TYPE_INT, 1, GTK_TYPE_POINTER);
+		g_signal_new   ("free_match",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitSyncAbsClass, free_match),
+				NULL,
+				NULL,
+				gp_marshal_INT__POINTER,
+				G_TYPE_INT, 1, G_TYPE_POINTER);
 
 	pilot_conduit_sync_abs_signals[PREPARE] =
-		gtk_signal_new ("prepare",
-				GTK_RUN_LAST,
-				GTK_CLASS_TYPE (object_class),
-				GTK_SIGNAL_OFFSET (GnomePilotConduitSyncAbsClass, prepare),
+		g_signal_new   ("prepare",
+				G_TYPE_FROM_CLASS (object_class),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GnomePilotConduitSyncAbsClass, prepare),
+				NULL,
+				NULL,
 				gp_marshal_INT__POINTER_POINTER,
-				GTK_TYPE_INT, 2, GTK_TYPE_POINTER, GTK_TYPE_POINTER);
+				G_TYPE_INT, 2, G_TYPE_POINTER, G_TYPE_POINTER);
 
 	conduit_standard_class->copy_to_pilot = gnome_pilot_conduit_standard_real_copy_to_pilot;
 	conduit_standard_class->copy_from_pilot = gnome_pilot_conduit_standard_real_copy_from_pilot;
@@ -278,7 +308,7 @@ gnome_pilot_conduit_sync_abs_new (char *db_name,
 {
 	GnomePilotConduitSyncAbs *retval;
 
-	retval =  GNOME_PILOT_CONDUIT_SYNC_ABS (gtk_object_new (gnome_pilot_conduit_sync_abs_get_type (),
+	retval =  GNOME_PILOT_CONDUIT_SYNC_ABS (g_object_new (gnome_pilot_conduit_sync_abs_get_type (),
 								"GnomePilotConduitStandard::db_name", db_name,
 								"GnomePilotConduitStandard::creator_id", creator_id,
 								NULL));
@@ -638,8 +668,9 @@ gnome_pilot_conduit_sync_abs_pre_sync (SyncHandler *sh, int dbhandle, int *slow)
 	
 	dlp_ReadOpenDBInfo (dbinfo->pilot_socket, dbinfo->db_handle, &conduit->total_records);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [PRE_SYNC],
+			 0,
 			 dbinfo,
 			 &retval);
 
@@ -658,8 +689,9 @@ gnome_pilot_conduit_sync_abs_post_sync (SyncHandler *sh, int dbhandle)
 	conduit = ((gp_closure *)sh->data)->conduit;
 	dbinfo = ((gp_closure *)sh->data)->dbinfo;
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [POST_SYNC],
+			 0,
 			 dbinfo,
 			 &retval);
 	return retval;
@@ -676,8 +708,9 @@ gnome_pilot_conduit_sync_abs_set_pilot_id (SyncHandler *sh, DesktopRecord *dr, r
 	gdr = (GnomePilotDesktopRecord *)dr;
 	sync_abs_fill_gdr (gdr);
 	
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [SET_PILOT_ID],
+			 0,
 			 gdr, id, &retval);
 	
 	sync_abs_fill_dr (gdr);
@@ -696,8 +729,9 @@ gnome_pilot_conduit_sync_abs_set_status_cleared (SyncHandler *sh, DesktopRecord
 	gdr = (GnomePilotDesktopRecord *)dr;
 	sync_abs_fill_gdr (gdr);
 	
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [SET_STATUS_CLEARED],
+			 0,
 			 gdr, &retval);
 	
 	sync_abs_fill_dr (gdr);
@@ -714,8 +748,9 @@ gnome_pilot_conduit_sync_abs_for_each (SyncHandler *sh, DesktopRecord **dr)
 
 	conduit = ((gp_closure *)sh->data)->conduit;
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [FOR_EACH],
+			 0,
 			 &gdr, &retval);
 
 	if (gdr != NULL)
@@ -735,8 +770,9 @@ gnome_pilot_conduit_sync_abs_for_each_modified (SyncHandler *sh, DesktopRecord *
 
 	conduit = ((gp_closure *)sh->data)->conduit;
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [FOR_EACH_MODIFIED],
+			 0,
 			 &gdr, &retval);
 
 	if (gdr != NULL)
@@ -760,8 +796,9 @@ gnome_pilot_conduit_sync_abs_compare (SyncHandler *sh, PilotRecord *pr, DesktopR
 	gdr = (GnomePilotDesktopRecord *)dr;
 	sync_abs_fill_gdr (gdr);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [COMPARE],
+			 0,
 			 gdr, gpr, &retval);
 
 	g_free (gpr);
@@ -779,8 +816,9 @@ gnome_pilot_conduit_sync_abs_add_record (SyncHandler *sh, PilotRecord *pr)
 	conduit = ((gp_closure *)sh->data)->conduit;
 	gpr = sync_abs_pr_to_gpr (pr);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [ADD_RECORD],
+			 0,
 			 gpr, &retval);
 
 	g_free (gpr);
@@ -801,8 +839,9 @@ gnome_pilot_conduit_sync_abs_replace_record (SyncHandler *sh, DesktopRecord *dr,
 	sync_abs_fill_gdr (gdr);
 	gpr = sync_abs_pr_to_gpr (pr);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [REPLACE_RECORD],
+			 0,
 			 gdr, gpr, &retval);
 
 	g_free (gpr);
@@ -821,8 +860,9 @@ gnome_pilot_conduit_sync_abs_delete_record (SyncHandler *sh, DesktopRecord *dr)
 	gdr = (GnomePilotDesktopRecord *)dr;
 	sync_abs_fill_gdr (gdr);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [DELETE_RECORD],
+			 0,
 			 gdr, &retval);
 
 	return retval;
@@ -839,8 +879,9 @@ gnome_pilot_conduit_sync_abs_archive_record (SyncHandler *sh, DesktopRecord *dr,
 	gdr = (GnomePilotDesktopRecord *)dr;
 	sync_abs_fill_gdr (gdr);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [ARCHIVE_RECORD],
+			 0,
 			 gdr, archive ? TRUE : FALSE, &retval);
 
 	sync_abs_fill_dr (gdr);
@@ -859,8 +900,9 @@ gnome_pilot_conduit_sync_abs_match (SyncHandler *sh, PilotRecord *pr, DesktopRec
 	conduit = ((gp_closure *)sh->data)->conduit;
 	gpr = sync_abs_pr_to_gpr (pr);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [MATCH],
+			 0,
 			 gpr, &gdr, &retval);
 
 	if (gdr != NULL)
@@ -884,8 +926,9 @@ gnome_pilot_conduit_sync_abs_free_match (SyncHandler *sh, DesktopRecord *dr)
 	gdr = (GnomePilotDesktopRecord *)dr;
 	sync_abs_fill_gdr (gdr);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [FREE_MATCH],
+			 0,
 			 gdr, &retval);
 
 	return retval;
@@ -904,8 +947,9 @@ gnome_pilot_conduit_sync_abs_prepare (SyncHandler *sh, DesktopRecord *dr, PilotR
 	sync_abs_fill_gdr (gdr);
 	gpr = sync_abs_pr_to_gpr (pr);
 
-	gtk_signal_emit (GTK_OBJECT (conduit),
+	g_signal_emit   (GTK_OBJECT (conduit),
 			 pilot_conduit_sync_abs_signals [PREPARE],
+			 0,
 			 gdr, gpr, &retval);
 
 	*pr = sync_abs_gpr_to_pr (gpr);
