@@ -29,8 +29,9 @@
 #include <stdio.h>
 #include <string.h>
 #include "gnome-pilot-structures.h"
+#include <gpilotd/gnome-pilot-config.h>
 #include "gpilot-gui.h"
-#include <libgnome/libgnome.h>
+#include <glib/gi18n.h>
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -73,8 +74,8 @@ static GList *get_pilots (void);
 /* context stuff first */
 GPilotContext *gpilot_context_new (void)
 {
-	gchar *str;
-	gint id;
+	GKeyFile *kfile;
+	GError   *error = NULL;
 	
 	GPilotContext *retval;
 	
@@ -90,30 +91,33 @@ GPilotContext *gpilot_context_new (void)
 	retval->visor_err_handle = -1;
 #endif
 
-	/* get the id.  Does anyone know the valid range for this? */
-	srand (time (NULL));
-	id = 1 + ((guint) 1000000.0*rand ());
-	gnome_config_push_prefix ("/gnome-pilot.d/gpilotd/General/");
-	str = g_strdup_printf ("sync_PC_Id=%d", id);
-	retval->sync_PC_Id=gnome_config_get_int (str);
-	g_free (str);
+	kfile = get_gpilotd_kfile ();
 
-	/* if retval is the default value, store it now */
-	if (retval->sync_PC_Id == id) {
-		gnome_config_set_int ("sync_PC_Id",
+	retval->sync_PC_Id = g_key_file_get_integer (kfile, "General", "sync_PC_Id", &error);
+	if (error) {
+		/* get the id.  Does anyone know the valid range for this? */
+		srand (time (NULL));
+		retval->sync_PC_Id = 1 + ((guint) 1000000.0*rand ());
+		g_key_file_set_integer (kfile, "General", "sync_PC_Id",
 				     retval->sync_PC_Id);
+		g_error_free (error);
+		error = NULL;
+		
 	}
 
 	/* get progress stepping, default is -1, if default is returned,
 	   default to one and set it */
-	retval->progress_stepping = gnome_config_get_int ("progress_stepping=-1");
-	if (retval->progress_stepping ==  -1) {
+	retval->progress_stepping = g_key_file_get_integer (kfile, "General", "progress_stepping", &error);
+	if (error) {
 		retval->progress_stepping = 1;
-		gnome_config_set_int ("progress_stepping", retval->progress_stepping);
+		g_key_file_set_integer (kfile, "General", "progress_stepping", retval->progress_stepping);
+		g_error_free (error);
+		error = NULL;
 	}
 
-	gnome_config_pop_prefix ();
-	gnome_config_sync ();
+	save_gpilotd_kfile (kfile);
+	g_key_file_free (kfile);
+
 	return retval;
 }
 
@@ -123,6 +127,7 @@ GPilotContext *gpilot_context_new (void)
 void
 gpilot_context_init_user (GPilotContext *context)
 {
+	GKeyFile *kfile;
 	gchar *str;
 
 	if (!context->user) {
@@ -138,7 +143,10 @@ gpilot_context_init_user (GPilotContext *context)
 	context->devices = get_devices ();
 	context->pilots = get_pilots ();
 
-	context->sync_PC_Id=gnome_config_get_int ("/gnome-pilot.d/gpilotd/General/sync_PC_Id");
+	kfile = get_gpilotd_kfile ();
+	context->sync_PC_Id = g_key_file_get_integer (kfile, "General", "sync_PC_Id", NULL);
+
+	g_key_file_free (kfile);
 }
 
 void
@@ -242,9 +250,11 @@ gpilot_hdb_uucp_lock (GPilotDevice *device)
 	pid = getpid ();
 #ifndef LOCK_BINARY
 	snprintf(lock_buffer, 11, "%10d\n", pid);
-	write (fd, lock_buffer, 11);
+	if (write (fd, lock_buffer, 11) != 11)
+		g_warning("Failed to write to lock file");
 #else
-	write (fd, &pid, sizeof (pid));
+	if (write (fd, &pid, sizeof (pid)) != sizeof(pid))
+		g_warning("Failed to write to lock file");
 #endif
 	close (fd);
 	return 1;
@@ -460,7 +470,7 @@ gpilot_network_device_init (GPilotDevice *device)
 				"bind socket: err %d"),
 			    device->name, pi_net, ret);
 		}
-		g_warning(line);
+		g_warning("%s", line);
 		return -1;
 	}
 
@@ -543,46 +553,48 @@ gpilot_device_init (GPilotDevice *device)
 	return result;
 }
 
-static void
-gpilot_serial_device_load (GPilotDevice *device)
-{
-	device->port = gnome_config_get_string ("device");
-	device->speed = (guint)gnome_config_get_int ("speed=57600");
-}
-
-static void
-gpilot_network_device_load (GPilotDevice *device)
-{
-	device->ip = gnome_config_get_string ("ip");
-}
-
 gint
 gpilot_device_load (GPilotDevice *device, gint i)
 {
-	gchar prefix[40];
-	gchar tmp[40];
+	gchar *iDevice;
 	gint result = 0;
+	GKeyFile *kfile;
+	GError   *error = NULL;
 
 	g_return_val_if_fail (device != NULL,-1);
-	g_return_val_if_fail (prefix != NULL,-1);
 	
-	g_snprintf (prefix, 39,"/gnome-pilot.d/gpilotd/Device%d/", i);
-	gnome_config_push_prefix (prefix);
+	kfile = get_gpilotd_kfile ();
+	iDevice = g_strdup_printf ("Device%d", i);
 
-	g_snprintf (tmp, 39,"name=Cradle%d", i);
-	device->type = gnome_config_get_int ("type=0");
-	device->name = gnome_config_get_string (tmp);
-	device->timeout = gnome_config_get_int ("timeout=3");
+	device->type = g_key_file_get_integer (kfile, iDevice, "type", &error);
+	if (error) {
+		g_error_free (error);
+		error = NULL;
+		device->type = 0;
+	}
+	device->name = g_key_file_get_string (kfile, iDevice, "name", NULL);
+	device->timeout = g_key_file_get_integer (kfile, iDevice, "timeout", &error);
+	if (error) {
+		g_error_free (error);
+		error = NULL;
+		device->timeout = 3;
+	}
 
 	switch (device->type) {
 	case PILOT_DEVICE_SERIAL:
 	case PILOT_DEVICE_USB_VISOR:
 	case PILOT_DEVICE_IRDA:
 		/* These devices share the serial loader */
-		gpilot_serial_device_load (device);
+		device->port = g_key_file_get_string (kfile, iDevice, "device", NULL);
+		device->speed = (guint)g_key_file_get_integer (kfile, iDevice, "speed", &error);
+		if (error) {
+			g_error_free (error);
+			error = NULL;
+			device->speed = 57600;
+		}
 		break;
 	case PILOT_DEVICE_NETWORK:
-		gpilot_network_device_load (device);
+		device->ip = g_key_file_get_string (kfile, iDevice, "ip", NULL);
 		break;
 	case PILOT_DEVICE_BLUETOOTH:
 		break; /* no further info required */
@@ -590,7 +602,8 @@ gpilot_device_load (GPilotDevice *device, gint i)
 		g_warning (_("Unknown device type"));
 	}
 
-	gnome_config_pop_prefix ();
+	g_free (iDevice);
+	g_key_file_free (kfile);
 
 	return result;
 }
@@ -656,8 +669,11 @@ get_devices (void)
 {
 	GList * retval = NULL;
 	int n, i, final;
-  
-	final = n = gnome_config_get_int ("/gnome-pilot.d/gpilotd/General/num_devices=0");
+	GKeyFile *kfile;
+
+	kfile = get_gpilotd_kfile ();
+
+	final = n = g_key_file_get_integer (kfile, "General", "num_devices", NULL);
 
 	if (n==0) {
 		g_warning (_("Number of devices is configured to 0"));
@@ -686,6 +702,7 @@ get_devices (void)
 		g_warning (_("No accessible devices available"));
 	}
 
+	g_key_file_free (kfile);
 	return retval;
 }
 
@@ -694,8 +711,11 @@ get_pilots (void)
 {
 	GList * retval = NULL;
 	int n, i;
+	GKeyFile *kfile;
+
+	kfile = get_gpilotd_kfile ();
   
-	n = gnome_config_get_int ("/gnome-pilot.d/gpilotd/General/num_pilots=0");
+	n = g_key_file_get_integer (kfile, "General", "num_pilots", NULL);
 
 	if (n==0) {
 		g_warning (_("Number of PDAs is configured to 0"));
@@ -713,11 +733,11 @@ get_pilots (void)
 		gpilot_pilot_init (pilot, i);
 		retval = g_list_append (retval, pilot);
 	}
+
+	g_key_file_free (kfile);
 	return retval;
 }
 
-
-
 GPilotPilot *
 gpilot_pilot_new (void)
 {
@@ -730,27 +750,29 @@ void
 gpilot_pilot_init (GPilotPilot *pilot, 
 		   gint i)
 {
-	gchar *prefix;
+	gchar *iPilot;
+	GKeyFile *kfile;
 
 	/* set up stuff  */
 	g_free (pilot->name);
 	g_free (pilot->passwd);
 	g_free (pilot->pilot_username);
 	g_free (pilot->pilot_charset);
-	prefix = g_strdup_printf ("/gnome-pilot.d/gpilotd/Pilot%d/", i);
-	gnome_config_push_prefix (prefix);
+
+	kfile = get_gpilotd_kfile ();
+	iPilot = g_strdup_printf ("Pilot%d", i);
 
 	/* start filling in fields */
-	pilot->name = gnome_config_get_string("name");
-	pilot->pilot_id = gnome_config_get_int("pilotid");
-	pilot->pilot_username = gnome_config_get_string("pilotusername");
-	pilot->passwd = gnome_config_get_string("password");
-	pilot->creation = gnome_config_get_int ("creation");
-	pilot->romversion = gnome_config_get_int ("romversion");
+	pilot->name = g_key_file_get_string (kfile, iPilot, "name", NULL);
+	pilot->pilot_id = g_key_file_get_integer (kfile, iPilot, "pilotid", NULL);
+	pilot->pilot_username = g_key_file_get_string (kfile, iPilot, "pilotusername", NULL);
+	pilot->passwd = g_key_file_get_string (kfile, iPilot, "password", NULL);
+	pilot->creation = g_key_file_get_integer (kfile, iPilot, "creation", NULL);
+	pilot->romversion = g_key_file_get_integer (kfile, iPilot, "romversion", NULL);
 	pilot->number=i;
-	pilot->sync_options.basedir = gnome_config_get_string("basedir");
+	pilot->sync_options.basedir = g_key_file_get_string (kfile, iPilot, "basedir", NULL);
 #ifdef PILOT_LINK_0_12
-	pilot->pilot_charset = gnome_config_get_string("charset");
+	pilot->pilot_charset = g_key_file_get_string (kfile, iPilot, "charset", NULL);
 	/* If no charset has been specified by user, fall back
 	 * to the PILOT_CHARSET environment variable, if that
 	 * has been specified.
@@ -771,9 +793,8 @@ gpilot_pilot_init (GPilotPilot *pilot,
 	pilot->pilot_charset=NULL;
 #endif
 
-
-	gnome_config_pop_prefix ();
-	g_free(prefix);
+	g_key_file_free (kfile);
+	g_free (iPilot);
 }
 
 void
