@@ -23,14 +23,10 @@
 #ifndef _GPILOT_GUI_H_
 #define _GPILOT_GUI_H_
 #include <glib.h>
-#include <libgnomeui/gnome-messagebox.h>
 #include "gnome-pilot-structures.h"
 
-void gpilot_gui_run_dialog(gchar* type,gchar*,...);
-
-#define gpilot_gui_warning_dialog(format,args...) gpilot_gui_run_dialog(GNOME_MESSAGE_BOX_WARNING,format,##args)
-
-#define gpilot_gui_error_dialog(format,args...) gpilot_gui_run_dialog(GNOME_MESSAGE_BOX_ERROR,format,##args)
+void gpilot_gui_warning_dialog (gchar *mesg, ...);
+void gpilot_gui_error_dialog (gchar *mesg, ...);
 
 /* given a pilot or pilot==null,
    if pilot!=NULL, ask if this is the pilot to restore,
